import 'dart:convert';

import 'media_model.dart';

class PostReceiverRequest {
  String? searchVal;
  int? pageSize;
  int? pageNumber;
  String? type;
  int? businessId;
  String? postType;

  PostReceiverRequest(
      {this.searchVal,
      this.pageSize,
      this.pageNumber,
      this.type,
      this.postType,
      this.businessId});

  PostReceiverRequest.fromJson(Map<String, dynamic> json) {
    searchVal = json['searchVal'];
    pageSize = json['page_size'];
    pageNumber = json['page_number'];
    type = json['type'];
    businessId = json['business_id'];
    postType = json['post_type'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['searchVal'] = this.searchVal;
    data['page_size'] = this.pageSize;
    data['page_number'] = this.pageNumber;
    data['type'] = this.type;
    data['business_id'] = this.businessId;
    data['post_type'] = this.postType;
    return data;
  }
}

class PostReceiverResponse {
  String? statusCode;
  String? message;
  List<PostReceiverListItem?>? rows;
  int? total;

  PostReceiverResponse({this.statusCode, this.message, this.rows, this.total});

  PostReceiverResponse.fromJson(Map<String, dynamic> json) {
    statusCode = json['statusCode'];
    message = json['message'];
    if (json['rows'] != null) {
      rows = []; //PostReceiverListItem>();
      json['rows'].forEach((v) {
        rows!.add(PostReceiverListItem.fromJson(v));
      });
    }
    total = json['total'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['statusCode'] = statusCode;
    data['message'] = message;
    if (rows != null) {
      data['rows'] = rows!.map((v) => v!.toJson()).toList();
    }
    data['total'] = total;
    return data;
  }
}

class PostReceiverListItem {
  String? recipientTypeCode;
  String? recipientTypeDescription;
  String? recipientType;
  int? recipientTypeReferenceId;
  bool? isSelected;
  bool? isAllowed;
  String? allowedMsg;
  String? recipientImage;

  PostReceiverListItem(
      {this.recipientTypeCode,
      this.recipientTypeDescription,
      this.recipientType,
      this.recipientTypeReferenceId,
      this.isAllowed,
      this.allowedMsg,
      this.recipientImage,
      this.isSelected});

  PostReceiverListItem.fromJson(Map<String, dynamic> json) {
    recipientTypeCode = json['recipient_type_code'];
    recipientTypeDescription = json['recipient_type_description'];
    recipientType = json['recipient_type'];
    recipientTypeReferenceId = json['recipient_type_reference_id'];
    isSelected = json['is_selected'];
    isAllowed = json['is_allowed'];
    allowedMsg = json['allowed_msg'];
    recipientImage = json['recipient_image'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['recipient_type_code'] = recipientTypeCode;
    data['recipient_type_description'] = recipientTypeDescription;
    data['recipient_type'] = recipientType;
    data['recipient_type_reference_id'] = recipientTypeReferenceId;
    data['is_selected'] = isSelected;
    data['is_allowed'] = isAllowed;
    data['allowed_msg'] = allowedMsg;
    data['recipient_image'] = recipientImage;
    return data;
  }
}

class PostCreatePayload {
  int? postId;
  int? id;
  int? originalPsPostMainId;
  String? postOwnerType;
  int? postOwnerTypeId;
  int? postCreatedById;
  int? postBusinessId;
  String? postType;
  String? postCategory;
  String? postStatus;
  List<String?>? postRecipientType;
  int? postTypeReferenceId;
  ContentMetaCreate? contentMeta;
  List<MediaDetails>? mediaDetails;
  List<PostRecipientDetailItem>? postRecipientDetails;
  List<String?>? postKeywords;
  List<String>? postMentions;
  List<String?>? postSubTypes;
  String? sourceLink;
  String? postColor;
  //=============================lesson data
  String? coverImage;
  String? lessonType;
  LessonTopic? lessonTopic;
  List<LearnerListItem>? learnerItem;
  List<Affiliation>? affiliatedList;
  List<Programme>? programmesList;
  List<Classes>? classesList;
  List<Subjects>? subjectsList;
  List<Discipline>? disciplineList;
  ChapterItem? chapterItem;
  LessonDetails? lessonListItem;
  List<PostCreatePayload>? listOfLessons;
  List<CouponListItem>? giftCards;
  CommonCardData? celebrateCard;

  PostCreatePayload(
      {this.listOfLessons,
      this.lessonListItem,
      this.chapterItem,
      this.disciplineList,
      this.subjectsList,
      this.classesList,
      this.programmesList,
      this.affiliatedList,
      this.learnerItem,
      this.lessonTopic,
      this.lessonType,
      this.originalPsPostMainId,
      this.postOwnerType,
      this.postOwnerTypeId,
      this.postCreatedById,
      this.postBusinessId,
      this.postType,
      this.postCategory,
      this.postStatus,
      this.postRecipientType,
      this.postTypeReferenceId,
      this.contentMeta,
      this.mediaDetails,
      this.postKeywords,
      this.postMentions,
      this.postId,
      this.postColor,
      this.postRecipientDetails,
      this.postSubTypes,
      this.sourceLink,
      this.coverImage,
      this.giftCards,
      this.celebrateCard,
      this.id});

  PostCreatePayload.fromJson(Map<String, dynamic> json) {
    if (json['learner_category'] != null) {
      learnerItem = []; //LearnerListItem>();
      json['learner_category'].forEach((v) {
        learnerItem!.add(LearnerListItem.fromJson(v));
      });
    }
    ;
    lessonTopic = json['lesson_topic'] != null
        ? LessonTopic.fromJson(json['lesson_topic'])
        : null;
    celebrateCard = json['celebrate_card'] != null
        ? CommonCardData.fromJson(json['lesson_topic'])
        : null;
    chapterItem =
        json['chapter'] != null ? ChapterItem.fromJson(json['chapter']) : null;
    lessonListItem =
        json['lesson'] != null ? LessonDetails.fromJson(json['lesson']) : null;
    if (json['gift_cards'] != null) {
      giftCards = []; //Discipline>();
      json['gift_cards'].forEach((v) {
        giftCards!.add(CouponListItem.fromJson(v));
      });
    }
    if (json['discipline'] != null) {
      disciplineList = []; //Discipline>();
      json['discipline'].forEach((v) {
        disciplineList!.add(Discipline.fromJson(v));
      });
    }

    if (json['subjects'] != null) {
      subjectsList = []; //Subjects>();
      json['subjects'].forEach((v) {
        subjectsList!.add(Subjects.fromJson(v));
      });
    }
    if (json['classes'] != null) {
      classesList = []; //Classes>();
      json['classes'].forEach((v) {
        classesList!.add(Classes.fromJson(v));
      });
    }
    if (json['programme'] != null) {
      programmesList = []; //Programme>();
      json['programme'].forEach((v) {
        programmesList!.add(Programme.fromJson(v));
      });
    }

    if (json['affiliation'] != null) {
      affiliatedList = []; //Affiliation>();
      json['affiliation'].forEach((v) {
        affiliatedList!.add(Affiliation.fromJson(v));
      });
    }
    lessonType = json['lesson_type'];
    coverImage = json['cover_image'];
    postId = json['post_id'];
    originalPsPostMainId = json['original_ps_post_main_id'];
    postOwnerType = json['post_owner_type'];
    postOwnerTypeId = json['post_owner_type_id'];
    postCreatedById = json['post_created_by_id'];
    postBusinessId = json['post_business_id'];
    postType = json['post_type'];
    postCategory = json['post_category'];
    postStatus = json['post_status'];
    postRecipientType = json['post_recipient_type'] != null
        ? json['post_recipient_type'].cast<String>()
        : null;
    postTypeReferenceId = json['post_type_reference_id'];
    id = json['id'];
    sourceLink = json['source_link'];
    postColor = json['post_color'];
    postRecipientDetails = json['post_recipient_details'];
    contentMeta = json['content_meta'] != null
        ? ContentMetaCreate.fromJson(json['content_meta'])
        : null;
    if (json['media_details'] != null) {
      mediaDetails = []; //MediaDetails>();
      json['media_details'].forEach((v) {
        mediaDetails!.add(MediaDetails.fromJson(v));
      });
    }
    postKeywords = json['post_keywords'] != null
        ? json['post_keywords'].cast<String>()
        : null;
    postMentions = json['post_mentions'] != null
        ? json['post_mentions'].cast<String>()
        : null;
    postSubTypes = json['post_sub_types'] != null
        ? json['post_sub_types'].cast<String>()
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['learner_category'] = learnerItem;
    data['lesson_topic'] = lessonTopic;
    data['chapter'] = chapterItem;
    data['lesson'] = lessonListItem;
    data['discipline'] = disciplineList;
    data['subjects'] = subjectsList;
    data['classes'] = classesList;
    data['programme'] = programmesList;
    data['affiliation'] = affiliatedList;
    data['lesson_type'] = lessonType;
    data['original_ps_post_main_id'] = originalPsPostMainId;
    data['post_owner_type'] = postOwnerType;
    data['post_owner_type_id'] = postOwnerTypeId;
    data['post_created_by_id'] = postCreatedById;
    data['post_business_id'] = postBusinessId;
    data['post_type'] = postType;
    data['post_category'] = postCategory;
    data['post_status'] = postStatus;
    data['post_recipient_type'] = postRecipientType;
    data['post_type_reference_id'] = postTypeReferenceId;
    data['post_id'] = postId;
    data['id'] = id;
    data['post_color'] = postColor;
    data['cover_image'] = coverImage;
    data['post_recipient_details'] = postRecipientDetails;
    if (contentMeta != null) {
      data['content_meta'] = contentMeta!.toJson();
    }
    if (mediaDetails != null) {
      data['media_details'] = mediaDetails!.map((v) => v.toJson()).toList();
    }
    data['post_keywords'] = postKeywords;
    data['post_mentions'] = postMentions;
    data['post_sub_types'] = postSubTypes;
    data['source_link'] = sourceLink;
    data['gift_cards'] = giftCards;
    data['celebrate_card'] = celebrateCard;
    return data;
  }
}

class Affiliation {
  int? id;
  String? organizationCode;
  String? organizationName;

  Affiliation({this.id, this.organizationCode, this.organizationName});

  Affiliation.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    organizationCode = json['organization_code'];
    organizationName = json['organization_name'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['organization_code'] = organizationCode;
    data['organization_name'] = organizationName;
    return data;
  }
}

class Programme {
  int? id;
  String? programCode;
  String? programName;

  Programme({this.id, this.programCode, this.programName});

  Programme.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    programCode = json['program_code'];
    programName = json['program_name'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['program_code'] = programCode;
    data['program_name'] = programName;
    return data;
  }
}

class Discipline {
  int? id;
  String? departmentCode;
  String? departmentName;

  Discipline({this.id, this.departmentCode, this.departmentName});

  Discipline.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    departmentCode = json['department_code'];
    departmentName = json['department_name'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['department_code'] = departmentCode;
    data['department_name'] = departmentName;
    return data;
  }
}

class Classes {
  int? id;
  String? classCode;
  String? className;

  Classes({this.id, this.classCode, this.className});

  Classes.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    classCode = json['class_code'];
    className = json['class_name'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['class_code'] = classCode;
    data['class_name'] = className;
    return data;
  }
}

class Subjects {
  int? id;
  String? subjectCode;
  String? subjectName;

  Subjects({this.id, this.subjectCode, this.subjectName});

  Subjects.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    subjectCode = json['subject_code'];
    subjectName = json['subject_name'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['subject_code'] = subjectCode;
    data['subject_name'] = subjectName;
    return data;
  }
}

class ContentMetaCreate {
  String? title;
  String? subtitle1;
  String? subtitle2;
  String? meta;
  OtherPollRequest? others;

  ContentMetaCreate(
      {this.title, this.subtitle1, this.subtitle2, this.meta, this.others});

  ContentMetaCreate.fromJson(Map<String, dynamic> json) {
    title = json['title'];
    subtitle1 = json['subtitle1'];
    subtitle2 = json['subtitle2'];
    meta = json['meta'];
    others = json['others'] != null
        ? OtherPollRequest.fromJson(json['others'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['title'] = title;
    data['subtitle1'] = subtitle1;
    data['subtitle2'] = subtitle2;
    data['meta'] = meta;
    if (others != null) {
      data['others'] = others!.toJson();
    }
    return data;
  }
}

class OtherPollRequest {
  int? pollStart;
  int? pollEnd;
  int? totalResponses;
  List<Options>? options;
  int? submissionDateTime;
  int? maxMarks;
  List<String?>? subjects;

  OtherPollRequest(
      {this.pollStart,
      this.pollEnd,
      this.totalResponses,
      this.options,
      this.subjects,
      this.submissionDateTime,
      this.maxMarks});

  OtherPollRequest.fromJson(Map<String, dynamic> json) {
    pollStart = json['poll_start'];
    pollEnd = json['poll_end'];
    totalResponses = json['total_responses'];
    submissionDateTime = json['submission_datetime'];
    maxMarks = json['max_marks'];
    subjects =
        json['subjects'] != null ? json['subjects'].cast<String>() : null;
    if (json['options'] != null) {
      options = [];
      json['options'].forEach((v) {
        options!.add(Options.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['poll_start'] = pollStart;
    data['poll_end'] = pollEnd;
    data['total_responses'] = totalResponses;
    data['submission_datetime'] = submissionDateTime;
    data['max_marks'] = maxMarks;
    data['subjects'] = subjects;
    if (options != null) {
      data['options'] = options!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Options {
  String? option;
  int? optionSequence;
  int? numberSelected;
  int? percentage;

  Options(
      {this.option, this.optionSequence, this.numberSelected, this.percentage});

  Options.fromJson(Map<String, dynamic> json) {
    option = json['option'];
    optionSequence = json['option_sequence'];
    numberSelected = json['number_selected'];
    percentage = json['percentage'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['option'] = option;
    data['option_sequence'] = optionSequence;
    data['number_selected'] = numberSelected;
    data['percentage'] = percentage;
    return data;
  }
}

class MediaDetails {
  String? mediaType;
  String? mediaUrl;
  String? mediaThumbnailUrl;

  MediaDetails({this.mediaType, this.mediaUrl, this.mediaThumbnailUrl});

  MediaDetails.fromJson(Map<String, dynamic> json) {
    mediaType = json['media_type'];
    mediaUrl = json['media_url'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['media_type'] = mediaType;
    data['media_url'] = mediaUrl;
    return data;
  }
}

abstract class PostRecipientDetailItem {}

class CustomReceivers extends PostRecipientDetailItem {
  String? type;
  int? id;
  int? gender;
  int? minAge;
  int? maxAge;
  List<String?>? personTypes;
  List<String?>? loyaltyTypes;
  List<String?>? countryCodes;
  List<String?>? stateCodes;
  List<String?>? cityCodes;
  List<String?>? recipentType;
  List<String?>? postalCodes;

  List<String?>? personTypesNames;
  List<String?>? loyaltyTypesNames;
  List<String?>? countryCodesNames;
  List<String?>? stateCodesNames;
  List<String?>? cityCodesNames;

  List<String?>? postalCodesNames;

  CustomReceivers(
      {this.personTypesNames,
      this.loyaltyTypesNames,
      this.countryCodesNames,
      this.stateCodesNames,
      this.cityCodesNames,
      this.postalCodesNames,
      this.type,
      this.id,
      this.gender,
      this.recipentType,
      this.minAge,
      this.maxAge,
      this.personTypes,
      this.loyaltyTypes,
      this.countryCodes,
      this.stateCodes,
      this.cityCodes,
      this.postalCodes});

  CustomReceivers.fromJson(Map<String, dynamic> json) {
    type = json['type'];
    id = json['id'];
    gender = json['gender'];
    minAge = json['min_age'];
    maxAge = json['max_age'];
    recipentType = json['recipent_type'].cast<String>();
    personTypes = json['person_types'].cast<String>();
    loyaltyTypes = json['loyalty_types'].cast<String>();
    countryCodes = json['country_codes'].cast<String>();
    stateCodes = json['state_codes'].cast<String>();
    cityCodes = json['city_codes'].cast<String>();
    postalCodes = json['postal_codes'].cast<String>();

    personTypesNames = json['person_types_name'].cast<String>();
    loyaltyTypesNames = json['loyalty_types_name'].cast<String>();
    countryCodesNames = json['country_codes_name'].cast<String>();
    stateCodesNames = json['state_codes_name'].cast<String>();
    cityCodesNames = json['city_codes_name'].cast<String>();
    postalCodesNames = json['postal_codes_name'].cast<String>();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['type'] = type;
    data['id'] = id;
    data['gender'] = gender;
    data['min_age'] = minAge;
    data['max_age'] = maxAge;
    data['recipent_type'] = recipentType;
    data['person_types'] = personTypes;
    data['loyalty_types'] = loyaltyTypes;
    data['country_codes'] = countryCodes;
    data['state_codes'] = stateCodes;
    data['city_codes'] = cityCodes;
    data['postal_codes'] = postalCodes;

    data['person_types_name'] = personTypesNames;
    data['loyalty_types_name'] = loyaltyTypesNames;
    data['country_codes_name'] = countryCodesNames;
    data['state_codes_name'] = stateCodesNames;
    data['city_codes_name'] = cityCodesNames;
    data['postal_codes_name'] = postalCodesNames;
    return data;
  }
}

class NormalReceivers2 extends PostRecipientDetailItem {
  String? type;
  int? id;

  NormalReceivers2({this.type, this.id});

  NormalReceivers2.fromJson(Map<String, dynamic> json) {
    type = json['type'];
    id = json['id'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['type'] = type;
    data['id'] = id;
    return data;
  }
}

class NormalReceivers extends PostRecipientDetailItem {
  String? name;
  String? type;
  int? id;

  NormalReceivers({this.type, this.id, this.name});

  NormalReceivers.fromJson(Map<String, dynamic> json) {
    type = json['type'];
    id = json['id'];
    name = json['name'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['type'] = type;
    data['id'] = id;
    data['name'] = name;
    return data;
  }
}

class LearnerListItem {
  String? learnerCategoryCode;
  String? learnerCategoryName;
  String? learnerCategoryDescription;
  String? imageUrl;
  String? ageGroupStart;
  String? ageGroupEnd;
  bool? isSelected;
  int? learnerCategoryId;
  String? learnerCategoryType;

  LearnerListItem(
      {this.learnerCategoryCode,
      this.learnerCategoryName,
      this.learnerCategoryDescription,
      this.imageUrl,
      this.isSelected,
      this.ageGroupStart,
      this.ageGroupEnd,
      this.learnerCategoryType,
      this.learnerCategoryId});

  LearnerListItem.fromJson(Map<String, dynamic> json) {
    learnerCategoryCode = json['learner_category_code'];
    learnerCategoryName = json['learner_category_name'];
    learnerCategoryDescription = json['learner_category_description'];
    learnerCategoryType = json['learner_category_type'];
    imageUrl = json['image_url'];
    ageGroupStart = json['age_group_start'];
    ageGroupEnd = json['age_group_end'];
    learnerCategoryId = json['learner_category_id'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['learner_category_code'] = learnerCategoryCode;
    data['learner_category_name'] = learnerCategoryName;
    data['learner_category_type'] = learnerCategoryType;
    data['learner_category_description'] = learnerCategoryDescription;
    data['image_url'] = imageUrl;
    data['age_group_start'] = ageGroupStart;
    data['age_group_end'] = ageGroupEnd;
    data['learner_category_id'] = learnerCategoryId;
    return data;
  }
}

class LessonTopic {
  String? title;
  TopicListItem? topic;
  List<TopicListItem>? subtopic;

  LessonTopic({this.title, this.topic, this.subtopic});

  LessonTopic.fromJson(Map<String, dynamic> json) {
    title = json['title'];
    topic =
        json['topic'] != null ? TopicListItem.fromJson(json['topic']) : null;
    if (json['subtopic'] != null) {
      subtopic = []; //TopicListItem>();
      json['subtopic'].forEach((v) {
        subtopic!.add(TopicListItem.fromJson(v));
      });
    }
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['title'] = title;
    if (topic != null) {
      data['topic'] = topic!.toJson();
    }
    if (subtopic != null) {
      data['subtopic'] = subtopic!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class TopicListItem {
  String? topicName;
  String? topicCode;
  String? topicDescription;
  String? imageUrl;
  int? topicId;
  bool? isSelected;

  TopicListItem(
      {this.topicName,
      this.topicCode,
      this.topicDescription,
      this.imageUrl,
      this.isSelected,
      this.topicId});

  TopicListItem.fromJson(Map<String, dynamic> json) {
    topicName = json['topic_name'];
    topicCode = json['topic_code'];
    topicDescription = json['topic_description'];
    imageUrl = json['image_url'];
    topicId = json['topic_id'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['topic_name'] = topicName;
    data['topic_code'] = topicCode;
    data['topic_description'] = topicDescription;
    data['image_url'] = imageUrl;
    data['topic_id'] = topicId;
    return data;
  }
}

class ChapterItem {
  String? chapterName;
  int? id;

  ChapterItem({this.chapterName, this.id});

  ChapterItem.fromJson(Map<String, dynamic> json) {
    chapterName = json['chapter_name'];
    id = json['id'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['chapter_name'] = chapterName;
    data['id'] = id;
    return data;
  }
}

class LessonDetails {
  int? id;
  int? chapterId;
  String? lessonName;
  int? referenceId;
  String? referenceType;
  String? postRecipientStatus;

  LessonDetails(
      {this.id,
      this.chapterId,
      this.lessonName,
      this.referenceId,
      this.referenceType,
      this.postRecipientStatus});

  LessonDetails.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    chapterId = json['chapter_id'];
    lessonName = json['lesson_name'];
    referenceId = json['reference_id'];
    referenceType = json['reference_type'];
    postRecipientStatus = json['post_recipient_status'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['chapter_id'] = chapterId;
    data['lesson_name'] = lessonName;
    data['reference_id'] = referenceId;
    data['reference_type'] = referenceType;
    data['post_recipient_status'] = postRecipientStatus;
    return data;
  }
}

class CouponListItem {
  int? id;
  String? numberOfCoupon;
  String? couponCode;
  String? couponProvider;
  String? couponProviderLogo;
  String? couponText;
  String? couponImage;
  String? couponDiscountType;
  int? couponDiscount;
  int? rewardPointsRequired;
  String? couponTermsConditionsHeading;
  List<String>? couponTermsConditionsPoints;
  String? validFrom;
  String? validTill;
  String? couponStatus;
  String? createdDate;
  String? updatedDate;
  String? qrCode;

  CouponListItem(
      {this.id,
      this.numberOfCoupon,
      this.couponCode,
      this.couponProvider,
      this.couponProviderLogo,
      this.couponText,
      this.couponImage,
      this.couponDiscountType,
      this.couponDiscount,
      this.rewardPointsRequired,
      this.couponTermsConditionsHeading,
      this.couponTermsConditionsPoints,
      this.validFrom,
      this.validTill,
      this.couponStatus,
      this.createdDate,
      this.qrCode,
      this.updatedDate});

  CouponListItem.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    numberOfCoupon = json['number_of_coupon'];
    couponCode = json['coupon_code'];
    couponProvider = json['coupon_provider'];
    couponProviderLogo = json['coupon_provider_logo'];
    couponText = json['coupon_text'];
    couponImage = json['coupon_image'];
    couponDiscountType = json['coupon_discount_type'];
    couponDiscount = json['coupon_discount'];
    rewardPointsRequired = json['reward_points_required'];
    couponTermsConditionsHeading = json['coupon_terms_conditions_heading'];
    couponTermsConditionsPoints =
        json['coupon_terms_conditions_points'].cast<String>();
    validFrom = json['valid_from'];
    validTill = json['valid_till'];
    couponStatus = json['coupon_status'];
    createdDate = json['created_date'];
    updatedDate = json['updated_date'];
    qrCode = json['qr_code'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['number_of_coupon'] = numberOfCoupon;
    data['coupon_code'] = couponCode;
    data['coupon_provider'] = couponProvider;
    data['coupon_provider_logo'] = couponProviderLogo;
    data['coupon_text'] = couponText;
    data['coupon_image'] = couponImage;
    data['coupon_discount_type'] = couponDiscountType;
    data['coupon_discount'] = couponDiscount;
    data['reward_points_required'] = rewardPointsRequired;
    data['coupon_terms_conditions_heading'] = couponTermsConditionsHeading;
    data['coupon_terms_conditions_points'] = couponTermsConditionsPoints;
    data['valid_from'] = validFrom;
    data['valid_till'] = validTill;
    data['coupon_status'] = couponStatus;
    data['created_date'] = createdDate;
    data['updated_date'] = updatedDate;
    data['qr_code'] = qrCode;
    return data;
  }
}

class CommonCardData {
  List<Data>? data;
  List<SubRow>? subRow;
  String? id;
  Object? object;
  bool? isUserExist;
  String? userName;
  bool? isVerified;
  String? locality;
  String? localityBusiness;
  String? businessId;
  String? type;
  String? classStaffName;
  String? totalCount;
  String? cardName;
  String? cardNames;
  String? image;
  String? coverImage;
  String? name;
  String? backgroundColor;
  String? title;
  String? subTitle;
  bool? isIntroCard;
  bool? isEditable;
  String? textOne;
  String? textTwo;
  String? textThree;
  String? textFour;
  String? textFive;
  String? textSix;
  String? textSeven;
  String? textEight;
  String? textTen;
  String? textEleven;
  String? textTwelve;
  bool? isCurrent;
  String? textNine;
  bool? isFollow;
  bool? isFollow2;
  bool? isShowMore;
  bool? isBlur;
  String? urlOne;
  String? urlThree;
  String? urlFour;
  String? urlTwo;
  double? ratingValue;
  double? ratingValueFiveStar;
  double? ratingValueFourStar;
  double? ratingValueThreeStar;
  double? ratingValueTwoStar;
  double? ratingValueOneStar;
  int? progress;
  String? imageUrl;
  String? moneyVal;
  String? quote;
  int? givenRating;
  int? givenratingid;
  int? givenreviewid;
  String? givenReview;
  double? lat;
  double? lon;
  String? heading;
  String? coins;
  int? personId;

  CommonCardData.fromJson(Map<String, dynamic> json) {
    progress = json['progress'];
    lat = json['lat'];
    lon = json['lon'];
    subTitle = json['subTitle'];
    heading = json['heading'];
    coins = json['coins'];
    givenReview = json['givenReview'];
    givenreviewid = json['givenreviewid'];
    givenratingid = json['givenratingid'];
    id = json['id'];
    userName = json['user_name'];
    isVerified = json['is_user_verified'];
    givenRating = json["givenRating"];
    isUserExist = json['is_user_exist'];
    locality = json['locality'];
    type = json['type'];
    localityBusiness = json['locality_val'];
    isFollow2 = json['is_following'];
    businessId = json['business_id'];
    coverImage = json['cover_image'];
    name = json['name'];
    textTen = json['textTen'];
    name = json['name'];
    classStaffName = json['class_taecher_name'];
    textEleven = json['textEleven'];
    textTwelve = json['textTwelve'];
    isCurrent = json['is_current'];
    cardName = json['cardName'];
    totalCount = json['total_count'];
    textOne = json['textOne'];
    image = json['image'];
    backgroundColor = json['backgroundColor'];
    title = json['title'];
    isEditable = json['isEditable'];
    textNine = json['textNine'];
    isFollow = json['isFollow'];
    isShowMore = json['isShowMore'];
    isIntroCard = json['isIntroCard'];
    textTwo = json['textTwo'];
    textThree = json['textThree'];
    textFour = json['textFour'];
    textFive = json['textFive'];
    textSix = json['textSix'];
    textSeven = json['textSeven'];
    textEight = json['textEight'] != null
        ? json['textEight'].toString()
        : json['textEight'];
    urlOne = json['urlOne'];
    urlThree = json['urlThree'];
    urlFour = json['urlFour'];
    urlTwo = json['urlTwo'];
    isBlur = json['isBlur'];
    ratingValueFiveStar = json['ratingValueFiveStar'];
    ratingValueFourStar = json['ratingValueFourStar'];
    ratingValueThreeStar = json['ratingValueThreeStar'];
    ratingValueTwoStar = json['ratingValueTwoStar'];
    ratingValueOneStar = json['ratingValueOneStar'];
    ratingValue = json['ratingValue'];
    imageUrl = json['image_url'];
    moneyVal = json['money_val'];
    quote = json['quote'];
    personId = json['person_id'];

    if (json['subRow'] != null) {
      subRow = []; //SubRow>();
      json['subRow'].forEach((v) {
        subRow!.add(SubRow.fromJson(v));
      });
    }
    cardNames = json['card_name'];
    if (json['data'] != null) {
      data = []; //Data>();
      json['data'].forEach((v) {
        data!.add(Data.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (this.data != null) {
      data['data'] = this.data!.map((v) => v.toJson()).toList();
    }
    data['subTitle'] = subTitle;
    data['lat'] = lat;
    data['lon'] = lon;
    data['givenratingid'] = givenratingid;
    data['user_name'] = userName;
    data['givenreviewid'] = givenreviewid;
    data['givenReview'] = givenReview;
    data['money_val'] = moneyVal;
    data['quote'] = quote;
    data["givenRating"] = givenRating;
    data['is_user_verified'] = isVerified;
    data['progress'] = progress;
    data['id'] = id;
    data['card_name'] = cardNames;
    data['name'] = name;
    data['type'] = type;
    data['is_user_exist'] = isUserExist;
    data['locality_val'] = localityBusiness;
    data['locality'] = locality;
    data['is_following'] = isFollow2;
    data['business_id'] = businessId;
    data['cover_image'] = coverImage;
    data['class_taecher_name'] = classStaffName;
    data['is_current'] = isCurrent;
    data['total_count'] = totalCount;
    data['textNine'] = textNine;
    data['image'] = image;
    data['isFollow'] = isFollow;
    data['isShowMore'] = isShowMore;
    data['cardName'] = cardName;
    data['isEditable'] = isEditable;
    data['backgroundColor'] = backgroundColor;
    data['title'] = title;
    data['textOne'] = textOne;
    data['isIntroCard'] = isIntroCard;
    data['textTwo'] = textTwo;
    data['textThree'] = textThree;
    data['textFour'] = textFour;
    data['textFive'] = textFive;
    data['textSix'] = textSix;
    data['textSeven'] = textSeven;
    data['textEight'] = textEight;
    data['urlOne'] = urlOne;
    data['urlTwo'] = urlTwo;
    data['urlFour'] = urlFour;
    data['urlThree'] = urlThree;
    data['image_url'] = imageUrl;
    data['money_val'] = moneyVal;
    data['quote'] = quote;
    data['isBlur'] = isBlur;
    data['ratingValueFiveStar'] = ratingValueFiveStar;
    data['ratingValueFourStar'] = ratingValueFourStar;
    data['ratingValueThreeStar'] = ratingValueThreeStar;
    data['ratingValueTwoStar'] = ratingValueTwoStar;
    data['ratingValueOneStar'] = ratingValueOneStar;
    data['ratingValue'] = ratingValue;
    data['coins'] = coins;
    data['heading'] = heading;
    data['person_id'] = personId;
    if (subRow != null) {
      data['subRow'] = subRow!.map((v) => v.toJson()).toList();
    }
    return data;
  }

  CommonCardData({this.progress});
}

class MembersList {
  String? name;
  String? profileImage;

  MembersList({this.name, this.profileImage});

  MembersList.fromJson(Map<String, dynamic> json) {
    name = json['name'];
    profileImage = json['profile_image'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['name'] = name;
    data['profile_image'] = profileImage;
    return data;
  }
}

class Data {
  int? id;
  String? quotedByName;
  String? quoteText;
  String? suggestedType;
  String? quoteImageThumbnailUrl;
  String? quoteImageUrl;
  String? bannerText;
  String? bannerImageThumbnailUrl;
  String? bannerImageUrl;
  String? bannerSeq;
  String? title;
  String? subtitle;
  String? avatar;
  bool? isFollowed;
  int? postDatetime;
  bool? isBookmarked;
  String? postOwnerType;
  int? postOwnerTypeId;
  String? postType;
  int? postId;
  Null postTypeReferenceId;
  PostContent? postContent;
  bool? isRequestedByMember;
  String? roomOwnerType;
  int? roomOwnerTypeId;
  int? roomBusinessId;
  String? roomName;
  String? roomDescription;
  bool? isPrivate;
  bool? isSharable;
  String? roomStatus;
  String? roomType;
  String? roomCreatedByType;
  int? roomCreatedById;
  int? membersCount;
  String? membershipStatus;
  String? memberRoleType;
  String? roomProfileImageUrl;
  bool? isAutoGeneratedRoom;
  HeaderRoom? header;
  List<MembersList>? membersList;
  bool? isVoted;

  Data({
    this.id,
    this.quotedByName,
    this.quoteText,
    this.suggestedType,
    this.quoteImageThumbnailUrl,
    this.quoteImageUrl,
    this.bannerText,
    this.bannerImageThumbnailUrl,
    this.bannerImageUrl,
    this.bannerSeq,
    this.title,
    this.subtitle,
    this.avatar,
    this.isFollowed,
    this.postDatetime,
    this.isBookmarked,
    this.postOwnerType,
    this.postOwnerTypeId,
    this.postType,
    this.postId,
    this.postTypeReferenceId,
    this.postContent,
    this.roomOwnerType,
    this.roomOwnerTypeId,
    this.roomBusinessId,
    this.roomName,
    this.isRequestedByMember,
    this.roomDescription,
    this.isPrivate,
    this.isSharable,
    this.roomStatus,
    this.roomType,
    this.roomCreatedByType,
    this.roomCreatedById,
    this.membersCount,
    this.membershipStatus,
    this.memberRoleType,
    this.isAutoGeneratedRoom,
    this.header,
    this.membersList,
    this.roomProfileImageUrl,
    this.isVoted,
  });

  Data.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    suggestedType = json['suggested_type'];
    quotedByName = json['quoted_by_name'];
    quoteText = json['quote_text'];
    quoteImageThumbnailUrl = json['quote_image_thumbnail_url'];
    quoteImageUrl = json['quote_image_url'];
    bannerText = json['banner_text'];
    bannerImageThumbnailUrl = json['banner_image_thumbnail_url'];
    bannerImageUrl = json['banner_image_url'];
    bannerSeq = json['banner_seq'];
    title = json['title'];
    subtitle = json['subtitle'];
    avatar = json['avatar'];
    isFollowed = json['is_followed'];
    postDatetime = json['post_datetime'];
    isBookmarked = json['is_bookmarked'];
    postOwnerType = json['post_owner_type'];
    postOwnerTypeId = json['post_owner_type_id'];
    postType = json['post_type'];
    postId = json['post_id'];
    postTypeReferenceId = json['post_type_reference_id'];
    postContent = json['post_content'] != null
        ? PostContent.fromJson(json['post_content'])
        : null;
    isRequestedByMember = json['is_requested_by_member'];
    roomOwnerType = json['room_owner_type'];
    roomOwnerTypeId = json['room_owner_type_id'];
    roomBusinessId = json['room_business_id'];
    roomName = json['room_name'];
    roomDescription = json['room_description'];
    isPrivate = json['is_private'];
    isSharable = json['is_sharable'];
    roomStatus = json['room_status'];
    roomType = json['room_type'];
    roomCreatedByType = json['room_created_by_type'];
    roomCreatedById = json['room_created_by_id'];
    membersCount = json['members_count'];
    membershipStatus = json['membership_status'];
    memberRoleType = json['member_role_type'];
    roomProfileImageUrl = json['room_profile_image_url'];
    isAutoGeneratedRoom = json['is_auto_created'];
    isVoted = json['is_voted'];
    header =
        json['header'] != null ? HeaderRoom.fromJson(json['header']) : null;
    if (json['members_list'] != null) {
      membersList = []; //MembersList>();
      json['members_list'].forEach((v) {
        membersList!.add(MembersList.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['suggested_type'] = suggestedType;
    data['quoted_by_name'] = quotedByName;
    data['quote_text'] = quoteText;
    data['quote_image_thumbnail_url'] = quoteImageThumbnailUrl;
    data['quote_image_url'] = quoteImageUrl;
    data['banner_text'] = bannerText;
    data['banner_image_thumbnail_url'] = bannerImageThumbnailUrl;
    data['banner_image_url'] = bannerImageUrl;
    data['banner_seq'] = bannerSeq;
    data['title'] = title;
    data['subtitle'] = subtitle;
    data['avatar'] = avatar;
    data['is_followed'] = isFollowed;
    data['post_datetime'] = postDatetime;
    data['is_bookmarked'] = isBookmarked;
    data['post_owner_type'] = postOwnerType;
    data['post_owner_type_id'] = postOwnerTypeId;
    data['post_type'] = postType;
    data['post_id'] = postId;
    data['post_type_reference_id'] = postTypeReferenceId;
    if (postContent != null) {
      data['post_content'] = postContent!.toJson();
    }
    data['is_voted'] = isVoted;
    data['is_requested_by_member'] = isRequestedByMember;
    data['room_owner_type'] = roomOwnerType;
    data['room_owner_type_id'] = roomOwnerTypeId;
    data['room_business_id'] = roomBusinessId;
    data['room_name'] = roomName;
    data['room_description'] = roomDescription;
    data['is_private'] = isPrivate;
    data['is_sharable'] = isSharable;
    data['room_status'] = roomStatus;
    data['room_type'] = roomType;
    data['room_created_by_type'] = roomCreatedByType;
    data['room_created_by_id'] = roomCreatedById;
    data['members_count'] = membersCount;
    data['membership_status'] = membershipStatus;
    data['member_role_type'] = memberRoleType;
    data['room_profile_image_url'] = roomProfileImageUrl;
    data['is_auto_created'] = isAutoGeneratedRoom;
    if (header != null) {
      data['header'] = header!.toJson();
    }
    if (membersList != null) {
      data['members_list'] = membersList!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class HeaderRoom {
  String? title;
  List<Action>? action;
  String? avatar;
  double? rating;
  String? subtitle1;
  bool? isVerified;

  HeaderRoom(
      {this.title,
      this.action,
      this.avatar,
      this.rating,
      this.subtitle1,
      this.isVerified});

  HeaderRoom.fromJson(Map<String, dynamic> json) {
    title = json['title'];
    if (json['action'] != null) {
      action = []; //Action>();
      json['action'].forEach((v) {
        action!.add(Action.fromJson(v));
      });
    }
    avatar = json['avatar'];
    rating = json['rating'];
    subtitle1 = json['subtitle1'];
    isVerified = json['is_verified'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['title'] = title;
    if (action != null) {
      data['action'] = action!.map((v) => v.toJson()).toList();
    }
    data['avatar'] = avatar;
    data['rating'] = rating;
    data['subtitle1'] = subtitle1;
    data['is_verified'] = isVerified;
    return data;
  }
}

class SubRow {
  List<SubRowInternal>? subRow;
  List<String>? images;
  String? personType;
  String? locality;
  String? isUserAuthorized;
  int? starRatingId;
  String? imageUrl;
  String? childId;
  bool? isFollow2;
  String? standardExpertiseCategoryTypes;
  List<String>? abilites;
  String? businessCourse;
  String? businessSubject;
  String? businessAcademicYearId;
  String? standardExpertiseCategoryId;
  String? standardExpertiseCategoryTypeId;
  String? businessClassId;
  String? instSubjectId;
  int? allBusinesses;
  int? allBusinessesId;
  String? businessId;
  String? id;
  int? businessClass;
  int? rattingStar;
  double? avgRating;
  String? totalCount;
  String? language;
  String? course;
  String? department;
  String? gradientOne;
  String? gradientTwo;
  String? cardName;
  String? backgroundColor;
  String? title;
  bool? isEditable;
  bool? isIntroCard;
  String? textOne;
  String? textTwo;
  String? textThree;
  String? textFour;
  String? textFive;
  String? textSix;
  String? textSeven;
  String? textEight;
  bool? isFollow;
  bool? isShowMore;
  bool? isBlur;
  bool? isSelected;
  String? urlOne;
  String? urlThree;
  String? urlFour;
  String? urlTwo;
  String? ratingValue;
  String? ratingValueFiveStar;
  String? ratingValueFourStar;
  String? ratingValueThreeStar;
  String? ratingValueTwoStar;
  String? ratingValueOneStar;
  String? classStaffName;
  String? chairperson;

  SubRow.fromJson(Map<String, dynamic> json) {
    if (json['subRow'] != null) {
      subRow = []; //SubRowInternal>();
      json['subRow'].forEach((v) {
        subRow!.add(SubRowInternal.fromJson(v));
      });
    }
    images =
        json['imagesURL'] != null ? json['imagesURL'].cast<String>() : null;
    totalCount = json['total_count'];
    rattingStar = json['star_rating'];
    businessClass = json['business_class'];
    locality = json['locality'];
    isUserAuthorized = json['is_user_authorize'];
    chairperson = json['chairperson'];
    course = json['course'];
    department = json['department'];
    childId = json['child_id'];
    isFollow2 = json['is_following'];
    starRatingId = json['star_rating_id'];
    avgRating = json['average_rating'];
    id = json['id'] != null ? json['id'] : "";
    standardExpertiseCategoryTypeId = json['standardExpertiseCategoryTypes_id'];
    businessId = json['business_id'];
    standardExpertiseCategoryTypes = json['standardExpertiseCategoryTypes'];
    gradientOne = json['gradientOne'];
    gradientTwo = json['gradientTwo'];
    cardName = json['cardName'];
    textOne = json['textOne'];
    imageUrl = json['image_url'];
    personType = json['person_type'];
    businessCourse = json['business_course'];
    businessSubject = json['business_subject'];
    businessAcademicYearId = json['business_academic_year_id'];
    standardExpertiseCategoryId = json['standardExpertiseCategory_id'];
    businessClassId = json['business_class_id'];
    instSubjectId = json['business_subject_id'];
    classStaffName = json['class_taecher_name'];
    language = json['language'];
    backgroundColor = json['backgroundColor'];
    title = json['title'];
    isEditable = json['isEditable'];
    isFollow = json['isFollow'];
    isShowMore = json['isShowMore'];
    isIntroCard = json['isIntroCard'];
    textTwo = json['textTwo'];
    textThree = json['textThree'];
    textFour = json['textFour'];
    textFive = json['textFive'];
    textSix = json['textSix'];
    textSeven = json['textSeven'];
    textEight = json['textEight'];
    urlOne = json['urlOne'];
    urlThree = json['urlThree'];
    urlFour = json['urlFour'];
    urlTwo = json['urlTwo'];
    isBlur = json['isBlur'];
    ratingValueFiveStar = json['ratingValueFiveStar'];
    ratingValueFourStar = json['ratingValueFourStar'];
    ratingValueThreeStar = json['ratingValueThreeStar'];
    ratingValueTwoStar = json['ratingValueTwoStar'];
    ratingValueOneStar = json['ratingValueOneStar'];
    ratingValue = json['ratingValue'];
    allBusinesses = json['all_businesses'];
    allBusinessesId = json['all_businesses_id'];
    abilites =
        json['abilities'] != null ? json['abilities'].cast<String>() : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};

    if (subRow != null) {
      data['subRow'] = subRow!.map((v) => v.toJson()).toList();
    }
    data['business_class'] = businessClass;
    data['class_taecher_name'] = classStaffName;
    data['all_businesses_id'] = allBusinessesId;
    data['standardExpertiseCategoryTypes_id'] = standardExpertiseCategoryTypeId;
    data['business_subject_id'] = instSubjectId;
    data['id'] = id;
    data['is_user_authorize'] = isUserAuthorized;
    data['child_id'] = childId;
    data['is_following'] = isFollow2;
    data['locality'] = locality;
    data['business_id'] = businessId;
    data['standardExpertiseCategoryTypes'] = standardExpertiseCategoryTypes;
    data['language'] = language;
    data['course'] = course;
    data['image_url'] = imageUrl;
    data['chairperson'] = chairperson;
    data['star_rating_id'] = starRatingId;
    data['average_rating'] = avgRating;
    data['all_businesses'] = allBusinesses;
    data['business_course'] = businessCourse;
    data['business_subject'] = businessSubject;
    data['business_academic_year_id'] = businessAcademicYearId;
    data['standardExpertiseCategory_id'] = standardExpertiseCategoryId;
    data['business_class_id'] = businessClassId;
    data['abilities'] = abilites;
    data['star_rating'] = rattingStar;
    data['person_type'] = personType;
    data['imagesURL'] = images;
    data['isFollow'] = isFollow;
    data['total_count'] = totalCount;
    data['isShowMore'] = isShowMore;
    data['cardName'] = cardName;
    data['backgroundColor'] = backgroundColor;
    data['title'] = title;
    data['isEditable'] = isEditable;
    data['textOne'] = textOne;
    data['isIntroCard'] = isIntroCard;
    data['textTwo'] = textTwo;
    data['textThree'] = textThree;
    data['textFour'] = textFour;
    data['textFive'] = textFive;
    data['textSix'] = textSix;
    data['textSeven'] = textSeven;
    data['textEight'] = textEight;
    data['urlOne'] = urlOne;
    data['urlTwo'] = urlTwo;
    data['urlFour'] = urlFour;
    data['urlThree'] = urlThree;
    data['gradientOne'] = gradientOne;
    data['gradientTwo'] = gradientTwo;
    data['isBlur'] = isBlur;
    data['department'] = department;
    data['ratingValueFiveStar'] = ratingValueFiveStar;
    data['ratingValueFourStar'] = ratingValueFourStar;
    data['ratingValueThreeStar'] = ratingValueThreeStar;
    data['ratingValueTwoStar'] = ratingValueTwoStar;
    data['ratingValueOneStar'] = ratingValueOneStar;
    data['ratingValue'] = ratingValue;

    return data;
  }

  static Map<String, dynamic> toMap(SubRow s) => {
        'business_class': s.businessClass,
        'textThree': s.textThree,
      };

  static String encode(List<SubRow> s) => json.encode(
        s.map<Map<String, dynamic>>((s) => SubRow.toMap(s)).toList(),
      );

  static List<SubRow> decode(String musics) =>
      (json.decode(musics) as List<dynamic>)
          .map<SubRow>((item) => SubRow.fromJson(item))
          .toList();
}

class SubRowInternal {
  List<String>? images;
  String? personType;
  String? locality;
  String? isUserAuthorized;
  int? starRatingId;
  String? imageUrl;
  String? childId;
  bool? isFollow2;
  String? standardExpertiseCategoryTypes;
  List<String>? abilites;
  String? businessCourse;
  String? businessSubject;
  String? businessAcademicYearId;
  String? standardExpertiseCategoryId;
  String? standardExpertiseCategoryTypeId;
  String? businessClassId;
  String? instSubjectId;
  int? allBusinesses;
  int? allBusinessesId;
  String? businessId;
  String? id;
  int? businessClass;
  int? rattingStar;
  double? avgRating;
  String? totalCount;
  String? language;
  String? course;
  String? gradientOne;
  String? gradientTwo;
  String? cardName;
  String? backgroundColor;
  String? title;
  bool? isEditable;
  bool? isIntroCard;
  String? textOne;
  String? textTwo;
  String? textThree;
  String? textFour;
  String? textFive;
  String? textSix;
  String? textSeven;
  String? textEight;
  bool? isFollow;
  bool? isShowMore;
  bool? isBlur;
  String? urlOne;
  String? urlThree;
  String? urlFour;
  String? urlTwo;
  String? ratingValue;
  String? ratingValueFiveStar;
  String? ratingValueFourStar;
  String? ratingValueThreeStar;
  String? ratingValueTwoStar;
  String? ratingValueOneStar;
  String? classStaffName;
  String? chairperson;

  SubRowInternal.fromJson(Map<String, dynamic> json) {
    images =
        json['imagesURL'] != null ? json['imagesURL'].cast<String>() : null;
    totalCount = json['total_count'];
    rattingStar = json['star_rating'];
    locality = json['locality'];
    isUserAuthorized = json['is_user_authorize'];
    chairperson = json['chairperson'];
    course = json['course'];
    childId = json['child_id'];
    isFollow2 = json['is_following'];
    starRatingId = json['star_rating_id'];
    avgRating = json['average_rating'];
    id = json['id'] != null ? json['id'] : "";
    standardExpertiseCategoryTypeId = json['standardExpertiseCategoryTypes_id'];
    businessId = json['business_id'];
    standardExpertiseCategoryTypes = json['standardExpertiseCategoryTypes'];
    gradientOne = json['gradientOne'];
    gradientTwo = json['gradientTwo'];
    cardName = json['cardName'];
    textOne = json['textOne'];
    imageUrl = json['image_url'];
    personType = json['person_type'];
    businessCourse = json['business_course'];
    businessSubject = json['business_subject'];
    businessAcademicYearId = json['business_academic_year_id'];
    standardExpertiseCategoryId = json['standardExpertiseCategory_id'];
    businessClassId = json['business_class_id'];
    instSubjectId = json['business_subject_id'];
    classStaffName = json['class_taecher_name'];
    language = json['language'];
    backgroundColor = json['backgroundColor'];
    title = json['title'];
    isEditable = json['isEditable'];
    isFollow = json['isFollow'];
    isShowMore = json['isShowMore'];
    isIntroCard = json['isIntroCard'];
    textTwo = json['textTwo'];
    textThree = json['textThree'];
    textFour = json['textFour'];
    textFive = json['textFive'];
    textSix = json['textSix'];
    textSeven = json['textSeven'];
    textEight = json['textEight'];
    urlOne = json['urlOne'];
    urlThree = json['urlThree'];
    urlFour = json['urlFour'];
    urlTwo = json['urlTwo'];
    isBlur = json['isBlur'];
    ratingValueFiveStar = json['ratingValueFiveStar'];
    ratingValueFourStar = json['ratingValueFourStar'];
    ratingValueThreeStar = json['ratingValueThreeStar'];
    ratingValueTwoStar = json['ratingValueTwoStar'];
    ratingValueOneStar = json['ratingValueOneStar'];
    ratingValue = json['ratingValue'];
    allBusinesses = json['all_businesses'];
    allBusinessesId = json['all_businesses_id'];
    abilites =
        json['abilities'] != null ? json['abilities'].cast<String>() : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['class_taecher_name'] = classStaffName;
    data['all_businesses_id'] = allBusinessesId;
    data['standardExpertiseCategoryTypes_id'] = standardExpertiseCategoryTypeId;
    data['business_subject_id'] = instSubjectId;
    data['id'] = id;
    data['is_user_authorize'] = isUserAuthorized;
    data['child_id'] = childId;
    data['is_following'] = isFollow2;
    data['locality'] = locality;
    data['business_id'] = businessId;
    data['standardExpertiseCategoryTypes'] = standardExpertiseCategoryTypes;
    data['language'] = language;
    data['course'] = course;
    data['image_url'] = imageUrl;
    data['chairperson'] = chairperson;
    data['star_rating_id'] = starRatingId;
    data['average_rating'] = avgRating;
    data['all_businesses'] = allBusinesses;
    data['business_course'] = businessCourse;
    data['business_subject'] = businessSubject;
    data['business_academic_year_id'] = businessAcademicYearId;
    data['standardExpertiseCategory_id'] = standardExpertiseCategoryId;
    data['business_class_id'] = businessClassId;
    data['abilities'] = abilites;
    data['star_rating'] = rattingStar;
    data['person_type'] = personType;
    data['imagesURL'] = images;
    data['isFollow'] = isFollow;
    data['total_count'] = totalCount;
    data['isShowMore'] = isShowMore;
    data['cardName'] = cardName;
    data['backgroundColor'] = backgroundColor;
    data['title'] = title;
    data['isEditable'] = isEditable;
    data['textOne'] = textOne;
    data['isIntroCard'] = isIntroCard;
    data['textTwo'] = textTwo;
    data['textThree'] = textThree;
    data['textFour'] = textFour;
    data['textFive'] = textFive;
    data['textSix'] = textSix;
    data['textSeven'] = textSeven;
    data['textEight'] = textEight;
    data['urlOne'] = urlOne;
    data['urlTwo'] = urlTwo;
    data['urlFour'] = urlFour;
    data['urlThree'] = urlThree;
    data['gradientOne'] = gradientOne;
    data['gradientTwo'] = gradientTwo;
    data['isBlur'] = isBlur;
    data['ratingValueFiveStar'] = ratingValueFiveStar;
    data['ratingValueFourStar'] = ratingValueFourStar;
    data['ratingValueThreeStar'] = ratingValueThreeStar;
    data['ratingValueTwoStar'] = ratingValueTwoStar;
    data['ratingValueOneStar'] = ratingValueOneStar;
    data['ratingValue'] = ratingValue;

    return data;
  }
}

class PostContent {
  List<String>? extra;
  Footer? footer;
  Header? header;
  Content? content;
  Statistics? statistics;
  Specifications? specifications;

  PostContent(
      {this.extra,
      this.footer,
      this.header,
      this.content,
      this.statistics,
      this.specifications});

  PostContent.fromJson(Map<String, dynamic> json) {
    extra = json['extra'].cast<String>();
    footer = json['footer'] != null ? Footer.fromJson(json['footer']) : null;
    header = json['header'] != null ? Header.fromJson(json['header']) : null;
    content =
        json['content'] != null ? Content.fromJson(json['content']) : null;
    statistics = json['statistics'] != null
        ? Statistics.fromJson(json['statistics'])
        : null;
    specifications = json['specifications'] != null
        ? Specifications.fromJson(json['specifications'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['extra'] = extra;
    if (footer != null) {
      data['footer'] = footer!.toJson();
    }
    if (header != null) {
      data['header'] = header!.toJson();
    }
    if (content != null) {
      data['content'] = content!.toJson();
    }
    if (statistics != null) {
      data['statistics'] = statistics!.toJson();
    }
    if (specifications != null) {
      data['specifications'] = specifications!.toJson();
    }
    return data;
  }
}

class Footer {
  List<String>? action;
  String? lastComment;

  Footer({this.action, this.lastComment});

  Footer.fromJson(Map<String, dynamic> json) {
    action = json['action'].cast<String>();
    lastComment = json['last_comment'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['action'] = action;
    data['last_comment'] = lastComment;
    return data;
  }
}

class Header {
  List<String>? extra;
  String? title;
  List<Action>? action;
  String? avatar;
  String? layout;
  String? subtitle1;
  Null subtitle2;
  bool? isVerified;

  Header(
      {this.extra,
      this.title,
      this.action,
      this.avatar,
      this.layout,
      this.subtitle1,
      this.isVerified,
      this.subtitle2});

  Header.fromJson(Map<String, dynamic> json) {
    extra = json['extra'].cast<String>();
    title = json['title'];
    if (json['action'] != null) {
      action = []; //Action>();
      json['action'].forEach((v) {
        action!.add(Action.fromJson(v));
      });
    }
    avatar = json['avatar'];
    layout = json['layout'];
    layout = json['layout'];
    isVerified = json['is_verified'];
    subtitle2 = json['subtitle2'];
    subtitle1 = json['subtitle1'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['extra'] = extra;
    data['title'] = title;
    if (action != null) {
      data['action'] = action!.map((v) => v.toJson()).toList();
    }
    data['is_verified'] = isVerified;
    data['avatar'] = avatar;
    data['layout'] = layout;
    data['subtitle1'] = subtitle1;
    data['subtitle2'] = subtitle2;
    return data;
  }
}

class Action {
  String? type;
  bool? value;

  Action({this.type, this.value});

  Action.fromJson(Map<String, dynamic> json) {
    type = json['type'];
    value = json['value'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['type'] = type;
    data['value'] = value;
    return data;
  }
}

class Content {
  List<Media>? media;
  ContentMeta? contentMeta;
  String? typeHeading;
  List<dynamic>? keywords;
  List<dynamic>? mentions;
  Content({this.media, this.contentMeta});

  Content.fromJson(Map<String, dynamic> json) {
    keywords = json['keywords'];
    mentions = json['mentions'];
    typeHeading = json['type_heading'];
    if (json['media'] != null) {
      media = []; //Media>();
      json['media'].forEach((v) {
        media!.add(Media.fromJson(v));
      });
    }
    contentMeta = json['content_meta'] != null
        ? ContentMeta.fromJson(json['content_meta'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['keywords'] = keywords;
    data['mentions'] = mentions;
    data['type_heading'] = typeHeading;
    if (media != null) {
      data['media'] = media!.map((v) => v.toJson()).toList();
    }
    if (contentMeta != null) {
      data['content_meta'] = contentMeta!.toJson();
    }
    return data;
  }
}

class ContentMeta {
  String? meta;
  String? title;
  String? subtitle1;
  String? subtitle2;
  OtherPollRequest? others;

  ContentMeta(
      {this.meta, this.title, this.subtitle1, this.subtitle2, this.others});

  ContentMeta.fromJson(Map<String, dynamic> json) {
    meta = json['meta'];
    title = json['title'];
    subtitle1 = json['subtitle1'];
    subtitle2 = json['subtitle2'];
    others = json['others'] != null
        ? OtherPollRequest.fromJson(json['others'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['meta'] = meta;
    data['title'] = title;
    data['subtitle1'] = subtitle1;
    data['subtitle2'] = subtitle2;
    if (others != null) {
      data['others'] = others!.toJson();
    }
    return data;
  }
}

class Statistics {
  int? starRating;
  int? commentCount;

  Statistics({this.starRating, this.commentCount});

  Statistics.fromJson(Map<String, dynamic> json) {
    starRating = json['star_rating'];
    commentCount = json['comment_count'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['star_rating'] = starRating;
    data['comment_count'] = commentCount;
    return data;
  }
}

class Specifications {
  int? size;
  int? width;
  int? height;
  String? color;

  Specifications({this.size, this.width, this.height, this.color});

  Specifications.fromJson(Map<String, dynamic> json) {
    size = json['size'];
    width = json['width'];
    height = json['height'];
    color = json['color'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['size'] = size;
    data['width'] = width;
    data['height'] = height;
    data['color'] = color;
    return data;
  }
}
