import 'dart:io';

import 'package:audioplayers/audioplayers.dart';

import 'package:flutter/material.dart';

import '../utils/colors.dart';
import '../utils/hexColors.dart';


class AudioWidget extends StatefulWidget{

 final  String url;

  const AudioWidget({Key? key, required this.url}) : super(key: key);
  @override
  AudioWidgetState createState() => AudioWidgetState(

  );
}

class AudioWidgetState extends State<AudioWidget> {

  AudioCache audioCache = AudioCache();
  AudioPlayer advancedPlayer = AudioPlayer();
  bool isPlaying=false;
  bool isResume=false;
  double max=0.0;
  double current=0.0;
  String currentTime="00:00";
  @override
  void initState() {
    super.initState();

    if (Platform.isIOS) {
      audioCache.fixedPlayer?.notificationService.startHeadlessService();
    }
  }

  @override
  Widget build(BuildContext context) {
    advancedPlayer.onDurationChanged.listen((Duration d) {
      print('Max duration: $d');
      setState(() {
        max=d.inSeconds.toDouble();
      });
    });

    advancedPlayer.onAudioPositionChanged.listen((Duration  duration) {

      setState(() {
        current=duration.inSeconds.toDouble();
        int hours =  (duration.inMilliseconds.toInt())~/(1000 * 60 * 60);
        int minutes =  ((duration.inMilliseconds.toInt()) % (1000 * 60 * 60)) ~/ (1000 * 60);
        int seconds =  ((duration.inMilliseconds.toInt()) % (1000 * 60 * 60)) % (1000 * 60) ~/ 1000;
        currentTime=hours>0?hours.toString()+":":""  + (minutes>0?minutes.toString():"00")  +  ":"+  (seconds>0?seconds.toString():"00");

      });



    });

    advancedPlayer.onPlayerCompletion.listen((event) {


      Future.delayed(const Duration(milliseconds: 500), () {
        setState(() {
          isPlaying=false;
          current=0;
          currentTime="00:00";
        });
      });

    });

    return Container(
        height: 75,
        decoration: BoxDecoration(
          color: HexColor(AppColors.appColorBlueGrey),
          borderRadius: BorderRadius.circular(10.0),
        ),
        child: Row(
          children: [
            pauseButton(),
            Expanded(child: progressSlider()),
          ],
        ));
  }

  Widget pauseButton() {
    return IconButton(
      icon: Icon(isPlaying?Icons.pause_outlined
          :
      Icons.play_arrow
      ,
        color: HexColor(AppColors.appColorWhite),
        size: 30,

      ),
      onPressed: (){
        setState(() {
          isPlaying=!isPlaying;

        });

        _playPause();
      },
    );
  }


_playPause() async {
  isPlaying?
  await advancedPlayer.play(
    widget.url,
    isLocal: false,
  ):advancedPlayer.pause()
  ;
}

Widget progressSlider() {
    const textStyle = TextStyle(color: Colors.white);
    return Column(
      mainAxisSize: MainAxisSize.min,
      children: [
        Padding(
          padding: const EdgeInsets.symmetric(horizontal: 25.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text(currentTime.toString(), style: textStyle),

            ],
          ),
        ),
        SizedBox(

          height: 25,
          child: Slider(
            min: 0,
            max: max,
            value:current>=0 && current<=max? current:0,
            activeColor: Colors.white,
            inactiveColor: Colors.grey,
            onChanged: (value) {},
          ),
        )
      ],
    );
  }
}