import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/localization.dart';

import '../utils/colors.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import '../utils/toast_builder.dart';

class EditStatusSheet extends StatefulWidget {
  final String title;
  final bool isBothValueRequired;
  final String subTitle;
  final String firstItemHint;
  final String firstItemTag;

  final Widget firstItemIcon;
  final Widget secondItemIcon;
  final String secondItemHint;
  final String secondItemTag;

  final num? giftCash;
  final num? giftCoin;
  final num? redemptionPercentage;
  final num? redemptionCoins;
  final Function(num cash, num coin) nextCallBack;

  const EditStatusSheet(
      {Key? key,
      this.giftCash,
      this.giftCoin,
      this.redemptionPercentage,
      this.redemptionCoins,
      required this.title,
      this.isBothValueRequired = false,
      required this.subTitle,
      required this.nextCallBack,
      required this.secondItemIcon,
      required this.firstItemIcon,
      required this.firstItemHint,
      required this.firstItemTag,
      required this.secondItemHint,
      required this.secondItemTag})
      : super(key: key);

  @override
  EditStatusSheetState createState() => EditStatusSheetState();
}

class EditStatusSheetState extends State<EditStatusSheet> {
  GlobalKey<FormState> formKey = GlobalKey();
  final coinsController = TextEditingController();

  late TextStyleElements styleElements;

  @override
  initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    final coins = TextFormField(
      controller: coinsController,
      keyboardType: TextInputType.number,
      style: styleElements
          .subtitle1ThemeScalable(context)
          .copyWith(color: HexColor(AppColors.appColorBlack65)),
      decoration: InputDecoration(
        fillColor: Colors.black12,
        filled: true,
        hintText: widget.secondItemHint,
        contentPadding: const EdgeInsets.all(16),
        border: UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),
        floatingLabelBehavior: FloatingLabelBehavior.auto,
        labelText: widget.secondItemTag,
      ),
    );

    return Padding(
      padding: const EdgeInsets.all(4.0),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Padding(
            padding: const EdgeInsets.only(
                bottom: 30.0, left: 16, right: 16, top: 8),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              //Center Row contents horizontally,
              crossAxisAlignment: CrossAxisAlignment.start,
              //Center Row contents vertically,

              children: [
                Expanded(
                  child: Align(
                    alignment: Alignment.center,
                    child: Container(
                      child: Text(
                        widget.title,
                        textAlign: TextAlign.center,
                        style: styleElements
                            .subtitle1ThemeScalable(context)
                            .copyWith(fontWeight: FontWeight.bold),
                      ),
                    ),
                  ),
                ),
                Padding(
                  padding: const EdgeInsets.only(right:2.0),
                  child: Text(
                    "Submit",
                    textAlign: TextAlign.right,
                    style: styleElements.subtitle1ThemeScalable(context).copyWith(
                        fontWeight: FontWeight.bold,
                        color: HexColor((AppColors.blueApp))),
                  ),
                ),
              ],
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(12),
            child: Text(
              widget.subTitle,
              textAlign: TextAlign.center,
              style: styleElements.captionThemeScalable(context),
            ),
          ),
          const SizedBox(
            width: 20,
          ),
          Flexible(
              child: Padding(padding: const EdgeInsets.all(8.0), child: coins)),
          SizedBox(
            height: MediaQuery.of(context).viewInsets.bottom,
          )
        ],
      ),
    );
  }
}
