
import 'package:flutter/material.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';
import 'package:lead_management/presentation/utils/localization.dart';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:timeago/timeago.dart' as timeago;

import '../../data/models/hepdesk_chat_message.dart';
import '../utils/app_buttons.dart';
import '../utils/colors.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import '../utils/toast_builder.dart';
import '../utils/utility_class.dart';

class MessageWidgetStarRatings extends StatefulWidget {
  final String? outPutLan;
  final HelpDeskChatMessage? item;
  final Function(double, int)? callback;
  final int? id;
  final String? title;
  final String? ratingGiven;

  MessageWidgetStarRatings(
      {Key? key,
      this.outPutLan,
      this.item,
      this.callback,
      this.id,
      this.title,
      this.ratingGiven})
      : super(key: key);

  @override
  MessageWidgetStarRatingsState createState() => MessageWidgetStarRatingsState(
      outPutLan: outPutLan, ratingGiven: ratingGiven);
}

class MessageWidgetStarRatingsState extends State<MessageWidgetStarRatings> {
  String? outPutLan;

  double rating = 0.0;

  MessageWidgetStarRatingsState({this.outPutLan, this.ratingGiven});

  SharedPreferences? prefs;
  bool isTranslate = false;
  bool isTranslatedAlready = false;
  String? outPutCode;
  String? inputLan;
  String? replyMessageContent;
  String? translatedContentReply;
  String? messageContent;
  String? translatedMessageContent;
  String? ratingGiven;
  bool alreadyRated = true;

  @override
  void initState() {
    setPrefs();
    checkIfAlreadyRated();
    super.initState();
  }

  checkIfAlreadyRated() {
    alreadyRated = ratingGiven != null &&
        double.tryParse(ratingGiven!) != null &&
        double.parse(ratingGiven!) > 0;
  }

  Future<void> setPrefs() async {
    prefs = await SharedPreferences.getInstance();
  }

  @override
  Widget build(BuildContext context) {
    TextStyleElements? styleElements = TextStyleElements(context);
    return IntrinsicWidth(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.end,
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Align(
              alignment: Alignment.center,
              child: Text(
                  alreadyRated
                      ? LeadsLocalizations.of(context)!
                          .translate('thank_you_rating')
                      : widget.title!,
                  style: styleElements.subtitle1ThemeScalable(context))),

          Align(
            alignment: Alignment.center,
            child: Padding(
              padding: const EdgeInsets.only(top: 16.0, bottom: 8.0),
              child: RatingBar.builder(
                initialRating:
                    alreadyRated ? double.parse(ratingGiven ?? "0.0") : 0,
                minRating: 0,
                direction: Axis.horizontal,
                allowHalfRating: false,
                ignoreGestures: alreadyRated,
                itemCount: 5,
                itemSize: 36.0,
                glowColor: HexColor(AppColors.appMainColor),
                itemPadding: EdgeInsets.symmetric(horizontal: 4.0),
                itemBuilder: (context, _) => Icon(
                  Icons.star,
                  color: HexColor(AppColors.appMainColor),
                ),
                onRatingUpdate: (rating) {
                  this.rating = rating;
                },
              ),
            ),
          ),

          // InkWell(
          //   onTap: (){
          //     translate();
          //   },
          //
          //   onLongPress: (){openUpdateLanguagePage();},
          //   child: Padding(
          //     padding: const EdgeInsets.only(top:8.0),
          //     child: Icon(
          //
          //       Icons.translate,
          //       size: 20,
          //       color: HexColor(AppColors.appColorBlack35),
          //     ),
          //   ),
          // ),

          Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              Text(
                timeago.format(DateTime.fromMillisecondsSinceEpoch(
                    widget.item!.createdAt!)),
                style: styleElements
                    .captionThemeScalable(context)
                    .copyWith(color: HexColor(AppColors.appColorBlack35)),
              ),
            ],
          ),

          Padding(
            padding: const EdgeInsets.only(top: 8.0),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Expanded(
                  child: Visibility(
                    visible: !alreadyRated,
                    child: Container(
                      child: Align(
                        alignment: Alignment.center,
                        child: appTextButton(
                          onPressed: () {
                            setState(() {
                              ratingGiven = rating.toString();
                              checkIfAlreadyRated();
                            });
                            widget.callback!(rating, widget.id!);
                          },
                          child: Padding(
                            padding: const EdgeInsets.all(4.0),
                            child: Text(
                              LeadsLocalizations.of(context)!
                                  .translate('submit')
                                  .toUpperCase(),
                              style: styleElements
                                  .captionThemeScalable(context)
                                  .copyWith(
                                      color: HexColor(AppColors.appMainColor),
                                      fontWeight: FontWeight.bold),
                            ),
                          ),
                        ),
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }

  void translateDescription(String? outPutCode) {
    if (isTranslate) {
      setState(() {
        isTranslate = false;
      });
    } else if (isTranslatedAlready && !isTranslate) {
      setState(() {
        isTranslate = true;
      });
    } else {
      if (messageContent != null) {
        Utility()
            .translate(context, messageContent!, inputLan, outPutCode!, "html")
            .then((value) {
          print(value);
          setState(() {
            translatedMessageContent = value;
            isTranslate = true;
          });
        });
      }

      if (replyMessageContent != null) {
        Utility()
            .translate(context, replyMessageContent ?? "", inputLan,
                outPutCode!, "html")
            .then((value) {
          print(value);
          setState(() {
            translatedContentReply = value;
            isTranslate = true;
          });
        });
      }
    }
  }

  void translate() {
    if (outPutLan == null) {
      openUpdateLanguagePage();
    } else {
      translateDescription(outPutLan!);
    }
  }

  void openUpdateLanguagePage() async {
/*    var result = await Navigator.push(
        context,
        MaterialPageRoute(
            builder: (context) => UpdateLanguagePage(true, null, true)));
    if (result != null && result['code'] != null) {
      setState(() {
        outPutLan = result['code'];
        isTranslate = false;
        isTranslatedAlready = false;
      });

      translateDescription(outPutLan);
    } else {
      ToastBuilder().showToast(
          LeadsLocalizations.of(context)!
              .translate("select_translation_language"),
          context,
          HexColor(AppColors.information));
    }*/
  }
}
