import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:lead_management/presentation/common_widgets/product_add_delete_widget.dart';

import '../../data/models/product_response.dart';
import '../utils/colors.dart';
import '../utils/customcard.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';

class ProductListCard extends StatefulWidget {
  final Function() moreCallback;
  final ProductItem productData;

  ProductListCard({required this.moreCallback, required this.productData});

  @override
  ProductListCardState createState() => ProductListCardState();
}

class ProductListCardState extends State<ProductListCard> {
  late TextStyleElements styleElements;

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return appListCard(
      padding: const EdgeInsets.all(0),
      child: Stack(
        children: [
          Padding(
            padding: const EdgeInsets.all(12),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Center(
                  child: CachedNetworkImage(
                    imageUrl: widget.productData.productThumbnail!,
                    height: 100,
                    width: 100,
                  ),
                ),
                const SizedBox(
                  width: 16,
                ),
                Expanded(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.end,
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Text(
                        widget.productData.productBrandName!.toUpperCase(),
                        style: styleElements
                            .captionThemeScalable(context)
                            .copyWith(
                            fontWeight: FontWeight.bold,
                            color: HexColor(AppColors.primaryTextColor35)),
                      ),
                      Text(
                        widget.productData.productLabel!,
                        maxLines: 3,
                        overflow: TextOverflow.ellipsis,
                        style: styleElements
                            .subtitle2ThemeScalable(context)
                            .copyWith(
                            fontWeight: FontWeight.bold,
                            color: HexColor(AppColors.appColorBlack85)),
                      ),
                      Row(
                        children: [
                          Text(
                            widget.productData.productCategoryNames![0],
                            style: styleElements
                                .captionThemeScalable(context)
                                .copyWith(
                                color:
                                HexColor(AppColors.primaryTextColor35)),
                          ),
                          Padding(
                            padding: const EdgeInsets.symmetric(horizontal: 8),
                            child: Container(
                              height: 12,
                              width: 1,
                              color: HexColor(AppColors.appColorBlack35),
                            ),
                          ),
                          Text(
                            "2169869862195".toUpperCase(),
                            style: styleElements
                                .captionThemeScalable(context)
                                .copyWith(
                                color:
                                HexColor(AppColors.primaryTextColor35)),
                          ),
                        ],
                      ),
                      Row(
                        children: [
                          const Spacer(),
                          Text(
                            "₹${widget.productData.productMaxPrice}",
                            style: styleElements
                                .subtitle2ThemeScalable(context)
                                .copyWith(
                                color: HexColor(AppColors.appColorBlack35),
                                decoration: TextDecoration.lineThrough),
                          ),
                          const SizedBox(
                            width: 16,
                          ),
                          Text(
                            "₹${widget.productData.productMinPrice}",
                            style: styleElements
                                .subtitle2ThemeScalable(context)
                                .copyWith(
                              color: HexColor(AppColors.appColorBlack85),
                            ),
                          )
                        ],
                      ),
                      Row(

                        children: [
                          const Spacer(),
                          Align(
                              alignment: Alignment.bottomRight,
                              child: AddDeleteProductWidget()),
                        ],
                      ),
                    ],
                  ),
                ),

              ],
            ),
          ),
          Align(
            alignment: Alignment.topLeft,
            child: Container(

                decoration: BoxDecoration(
                    border: Border.all(
                      color: HexColor(AppColors.appMainColor),
                    ),

                    color:  HexColor(AppColors.appMainColor),
                    borderRadius: const BorderRadius.only(
                      topLeft:Radius.zero,
                      topRight: Radius.zero,
                      bottomLeft:Radius.circular(12.0),
                      bottomRight:Radius.circular(12.0),)),
                child: Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Text(
                    "-23 %",
                    style: styleElements.captionThemeScalable(context).copyWith(
                        fontWeight: FontWeight.bold,
                        color: HexColor(AppColors.appColorWhite)),
                  ),
                )),
          ),
        ],
      ),
    );
  }
}
