import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/localization.dart';

import '../pages/select_product_page.dart';
import '../utils/colors.dart';
import '../utils/custom_app_bar.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import '../utils/toast_builder.dart';
import 'button_filled.dart';

class ProductSheet extends StatefulWidget {
  final String title;

  final String subTitle;

  final Function(num cash, num coin) nextCallBack;

  const ProductSheet({
    Key? key,
    required this.title,
    required this.subTitle,
    required this.nextCallBack,
  }) : super(key: key);

  @override
  ProductSheetState createState() => ProductSheetState();
}

class ProductSheetState extends State<ProductSheet> {
  GlobalKey<FormState> formKey = GlobalKey();
  final coinsController = TextEditingController();

  late TextStyleElements styleElements;
  final GlobalKey<TypeListWidgetState> typeListKey = GlobalKey();

  @override
  initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    return SafeArea(
      child: Scaffold(
        appBar: appAppBar().getCustomAppBar(
          context,
          appBarTitle: "Lead registration",
          onBackButtonPress: () {
            Navigator.pop(context);
          },
        ),
        body: SingleChildScrollView(
          child: Padding(
            padding: const EdgeInsets.all(4.0),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
             
                Row(
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.start,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            "Name",
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements!.bodyText2ThemeScalable(context),
                          ),
                          Text(
                            "Savil Mehra",
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements!.subtitle1ThemeScalable(context),
                          ),
                        ],
                      ),
                    ),
                    const Spacer()
                  ],
                ),
                Row(
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.start,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            "Phone",
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements!.bodyText2ThemeScalable(context),
                          ),
                          Text(
                            "+91 9625678097",
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements!.subtitle1ThemeScalable(context),
                          ),
                        ],
                      ),
                    ),
                    const Spacer(),
                    Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.start,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            "Email",
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements!.bodyText2ThemeScalable(context),
                          ),
                          Text(
                            "savkahfay@gmail.com",
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements!.subtitle1ThemeScalable(context),
                          ),
                        ],
                      ),
                    )
                  ],
                ),
                Row(
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.start,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(
                            "Business Name",
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements!.bodyText2ThemeScalable(context),
                          ),
                          Text(
                            "Lava International",
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements!.subtitle1ThemeScalable(context),
                          ),
                        ],
                      ),
                    ),
                    const Spacer()
                  ],
                ),
                const SizedBox(
                  width: 8,
                ),
                TypeListWidget(
                    type: ProductBrandCategoryCatalogueType.product,
                    key: typeListKey,
                    fromType: ProductBrandCategoryCatalogueType.product,
                    isSelect: false,
                    countCallback: (int count) {
                      setState(() {});
                    }),

                const Padding(
                  padding: EdgeInsets.all(16.0),
                  child: Text("By registering this lead you confirm that all data provided is shared in compliance with applicable law and true to your knowledge."),
                ),

                Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: LargeButton(
                    name: "Submit",
                    offsetX: 95.0,
                    offsetY: 14.33,
                    callback: () {

                    },
                  ),
                ),
                SizedBox(
                  height: MediaQuery.of(context).viewInsets.bottom,
                )
              ],
            ),
          ),
        ),
      ),
    );
  }
}
