import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_linkify/flutter_linkify.dart';
import 'package:lead_management/presentation/utils/basicInfo.dart';
import 'package:lead_management/presentation/utils/localization.dart';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:timeago/timeago.dart' as timeago;
import 'package:url_launcher/url_launcher.dart';

import '../../data/models/hepdesk_chat_message.dart';
import '../../data/models/postlist.dart';
import '../utils/colors.dart';
import '../utils/hexColors.dart';
import '../utils/resolutionenums.dart';
import '../utils/serviceTypeEnums.dart';
import '../utils/text_styling.dart';
import '../utils/utility_class.dart';
import 'audio_widget.dart';
import 'custom_preview_link.dart';
import 'imgevideoFullScreenViewPage.dart';
import 'message_widget_star_ratings.dart';


class ReceiverWidgetHelpdesk extends StatefulWidget {
  final String? outPutLan;
  final bool? isGroupConversation;
  final String? textPreview;

  final String? conversationWithName;

  final int? userId;
  final int? pageNumber;
  final HelpDeskChatMessage? item;
  final Function(String, HelpDeskChatMessage, String) handleClickedOption;
  final CustomClipper<Path> clipper;
  final int responsiblePersonId;
  final String? ratingGiven;

  ReceiverWidgetHelpdesk(
      {Key? key,
      this.outPutLan,
      required this.conversationWithName,
      required this.handleClickedOption,
      required this.isGroupConversation,
      required this.userId,
      this.item,
      required this.pageNumber,
      required this.textPreview,
      required this.responsiblePersonId,
      required this.ratingGiven,
      required this.clipper})
      : super(key: key);

  @override
  ReceiverWidgetHelpdeskState createState() =>
      ReceiverWidgetHelpdeskState(outPutLan: outPutLan);
}

class ReceiverWidgetHelpdeskState extends State<ReceiverWidgetHelpdesk> {
  String? outPutLan;

  ReceiverWidgetHelpdeskState({this.outPutLan});
  BasicInfo basicInfo =BasicInfo();
  SharedPreferences? prefs;
  bool isTranslate = false;
  bool isTranslatedAlready = false;
  String? outPutCode;
  String? inputLan;
  String? replyMessageContent;
  String? translatedContentReply;
  String? messageContent;
  String? translatedMessageContent;
  TextStyleElements? styleElements;

  @override
  void initState() {
    setPrefs();
    super.initState();
  }

  Future<void> setPrefs() async {
    prefs = await SharedPreferences.getInstance();
  }

  @override
  Widget build(BuildContext context) {
    replyMessageContent = widget.item!.originalCommentContent;

    messageContent =
        widget.item!.contentType != null && widget.item!.contentType == "object"
            ? jsonDecode(widget.item!.content!)['message']
            : widget.item!.content!;
    styleElements = TextStyleElements(context);
    return popItem(
        IntrinsicWidth(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisSize: MainAxisSize.min,
            mainAxisAlignment: MainAxisAlignment.start,
            children: [
              Visibility(
                // ignore: unnecessary_null_comparison
                visible: widget.textPreview != null,
                child: CustomPreviewLink(
                    context, widget.textPreview ?? "", styleElements),
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.end,
                mainAxisSize: MainAxisSize.min,
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  getWidget(widget.item!),
                ],
              ),
            ],
          ),
        ),
        widget.item!,
        widget.conversationWithName ?? "");
  }

  void translateDescription(String? outPutCode) {
    if (isTranslate) {
      setState(() {
        isTranslate = false;
      });
    } else if (isTranslatedAlready && !isTranslate) {
      setState(() {
        isTranslate = true;
      });
    } else {
      if (messageContent != null) {
        Utility()
            .translate(context, messageContent!, inputLan, outPutCode!, "html")
            .then((value) {
          print(value);
          setState(() {
            translatedMessageContent = value;
            isTranslate = true;
          });
        });
      }

      if (replyMessageContent != null) {
        Utility()
            .translate(context, replyMessageContent ?? "", inputLan,
                outPutCode!, "html")
            .then((value) {
          print(value);
          setState(() {
            translatedContentReply = value;
            isTranslate = true;
          });
        });
      }
    }
  }

  Widget getWidget(HelpDeskChatMessage item) {
    var cardType = "";
    HelpdeskMessageContent? messageContentModel;
    if (widget.item!.contentType != null &&
        widget.item!.contentType == 'json') {
      messageContentModel =
          HelpdeskMessageContent.fromJson(jsonDecode(widget.item!.content!));
      cardType = messageContentModel.cardType!;
      messageContent = messageContentModel.text;
    } else {
      messageContent = widget.item!.content ?? "";
    }
    switch (cardType) {
      case "rating":
        {
          return MessageWidgetStarRatings(
            outPutLan: 'hi',
            item: widget.item,
            title: messageContentModel!.text,
            ratingGiven: widget.ratingGiven,
            id: messageContentModel.agentId,
            callback: (value, id) {
              submitRating(value, id);
            },
          );
        }
      default:
        return Padding(
          padding: const EdgeInsets.only(left: 8.0, right: 8.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.end,
            mainAxisSize: MainAxisSize.min,
            mainAxisAlignment: MainAxisAlignment.start,
            children: [
              Visibility(
                visible:
                    widget.item!.isReply != null && widget.item!.isReply == 1,
                child: Container(
                  decoration: BoxDecoration(
                      color: HexColor(AppColors.white_translucent),
                      border: Border.all(
                        color: HexColor(AppColors.white_translucent),
                      ),
                      borderRadius: BorderRadius.all(Radius.circular(8))),
                  child: Padding(
                    padding: const EdgeInsets.all(8.0),
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.start,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Visibility(
                          visible:
                              widget.item!.originalCommentMediaUrl != null &&
                                  widget.item!.originalCommentMediaUrl != "",
                          child: getMediaView(
                              widget.item!.originalCommentMediaUrl,
                              widget.item!.originalCommentMediaType,
                              widget.item!.originalCommentContentType,
                              0, widget.item!,1),
                        ),
                        Linkify(
                          onOpen: (link) async {
                            if (await canLaunch(link.url)) {
                              await launch(link.url);
                            } else {
                              throw 'error';
                            }
                          },
                          text: isTranslate
                              ? translatedContentReply ?? ""
                              : replyMessageContent ?? "",
                          style: styleElements!.subtitle1ThemeScalable(context),
                          linkStyle: TextStyle(
                              color: HexColor(AppColors.appMainColor)),
                        ),
                      ],
                    ),
                  ),
                ),
              ),
              Visibility(
                visible: widget.item!.mediaUrl != null &&
                    widget.item!.mediaUrl != "",
                child: getMediaView(
                    widget.item!.mediaUrl,
                    widget.item!.mediaType,
                    widget.item!.contentType,
                    widget.item!.isUploading, widget.item!,0),
              ),
              Flexible(
                child: Container(
                  width:
                      item.mediaUrl != null && item.mediaUrl != "" ? 200 : null,
                  alignment: item.mediaUrl != null && item.mediaUrl != ""
                      ? Alignment.topLeft
                      : null,
                  child: Linkify(
                    onOpen: (link) async {
                      if (await canLaunch(link.url)) {
                        await launch(link.url);
                      } else {
                        throw 'error';
                      }
                    },
                    text: isTranslate
                        ? translatedMessageContent ?? ""
                        : messageContent ?? "",
                    style: styleElements!.subtitle1ThemeScalable(context),
                    maxLines:
                        item.mediaUrl != null && item.mediaUrl != "" ? 2 : null,
                    linkStyle:
                        TextStyle(color: HexColor(AppColors.appMainColor)),
                  ),
                ),
              ),
              InkWell(
                onTap: () {
                  translate();
                },
                onLongPress: () {
                  openUpdateLanguagePage();
                },
                child: Padding(
                  padding: const EdgeInsets.only(top: 8.0),
                  child: Icon(
                    Icons.translate,
                    size: 20,
                    color: HexColor(AppColors.appColorBlack35),
                  ),
                ),
              ),
              Row(
                mainAxisSize: MainAxisSize.min,
                children: [
                  Text(
                    timeago.format(DateTime.fromMillisecondsSinceEpoch(
                        widget.item!.createdAt!)),
                    style: styleElements!
                        .captionThemeScalable(context)
                        .copyWith(color: HexColor(AppColors.appColorBlack35)),
                  ),
                ],
              ),
            ],
          ),
        );
    }
  }

  void submitRating(double rating, int agentId) async {
 /*   if (rating != 0.0 && rating > 0.0) {
      CreateRatingPayload payload = CreateRatingPayload();
      payload.ratingContextId = widget.responsiblePersonId;
      payload.ratingContextType = 'person';
      payload.ratingGivenById = prefs!.getInt(Strings.userId);
      // payload.ratingNoteId = prefs.getInt(Strings.businessId);
      payload.ratingSubjectId = widget.item!.ticketMainId;
      payload.ratingSubjectType = "ticket";
      payload.ratingGiven = rating.toString();
      var body = jsonEncode(payload);
      var res =
          await GenericCommentReviewFeedback(context, body).apiCreateRatings();
      if (res) {
        ToastBuilder().showToast(
            AppLocalizations.of(context)!.translate('successfully_submit'),
            context,
            HexColor(AppColors.information));
      }
      // Navigator.pop(context, true);
    } else {
      ToastBuilder().showToast(
          AppLocalizations.of(context)!.translate('please_give_rating'),
          context,
          HexColor(AppColors.information));
      // Navigator.pop(context, false);
    }*/
  }

  void translate() {
    if (outPutLan == null) {
      openUpdateLanguagePage();
    } else {
      translateDescription(outPutLan!);
    }
  }

  void openUpdateLanguagePage() async {
/*    var result = await Navigator.push(
        context,
        MaterialPageRoute(
            builder: (context) => UpdateLanguagePage(true, null, true)));
    if (result != null && result['code'] != null) {
      setState(() {
        outPutLan = result['code'];
        isTranslate = false;
        isTranslatedAlready = false;
      });

      translateDescription(outPutLan);
    } else {
      ToastBuilder().showToast(
          AppLocalizations.of(context)!
              .translate("select_translation_language"),
          context,
          HexColor(AppColors.information));
    }*/
  }

  getMediaView(String? mediaUrl, String? mediaType, String? contentType,
      int? isUploading,HelpDeskChatMessage item,int reply) {
    List<Media> mediaList = [];
    mediaList.add(Media(
        mediaUrl: item.isReply == 0
            ? item.mediaUrl ?? ""
            : item.originalCommentMediaUrl ?? "",
        mediaType: item.isReply == 0
            ? item.mediaType ?? ""
            : item.originalCommentMediaType ?? ""));
    return  reply == 0 &&   item.mediaType == "audio" ||
        reply == 1 && item.originalCommentMediaType == "audio"

        ?
    AudioWidget(url: basicInfo.baseUrl +(reply==1?item.originalCommentMediaUrl??"": item.mediaUrl??"")):
    GestureDetector(
      behavior: HitTestBehavior.translucent,
      onTap: () {
        if (mediaType == "image" || mediaType == "video")
          Navigator.of(context).push(MaterialPageRoute(
              builder: (context) => ImageVideoFullPage(
                  ownerId: widget.userId,
                  ownerType: "person",
                  mediaList: mediaList,
                  isWithOutData: true,
                  isLocalFile: isUploading == 1 ? true : false,
                  isMediaPage: true,
                  pageNumber: widget.pageNumber,
                  position: 0,
                  totalItems: 1)));
        else {
          launch(basicInfo.baseUrl + mediaUrl!);
        }
      },
      child: Container(
        padding: const EdgeInsets.all(4.0),
        height: 200,
        width: 200,
        child: Stack(
          children: [
            isUploading == 1
                ? SizedBox(
                    height: 200,
                    width: 200,
                    child: contentType == "image" || contentType == "video"
                        ? new Image.file(
                            contentType == "image"
                                ? File(mediaUrl ?? "")
                                : File(mediaUrl ?? ""),
                            fit: BoxFit.cover,
                          )
                        : SizedBox(
                            height: 200,
                            width: 200,
                            child: Image(
                              image: AssetImage(
                                mediaType == "pdf"
                                    ? 'assets/appimages/pdf.png'
                                    : 'assets/appimages/excel.png',
                              ),
                              fit: BoxFit.cover,
                            ),
                          ),
                  )
                : Stack(
                    children: [
                      new Container(
                        decoration: new BoxDecoration(
                          image: new DecorationImage(
                            image: contentType == "image"
                                ? new NetworkImage(
                                    Utility().getUrlForImage(
                                        mediaUrl ?? "",
                                        RESOLUTION_TYPE.R256,
                                        SERVICE_TYPE.PERSON),
                                  )
                                : new NetworkImage(Utility().getUrlForImage(
                                    (mediaUrl ?? ""),
                                    RESOLUTION_TYPE.R256,
                                    SERVICE_TYPE.PERSON)),
                            fit: BoxFit.cover,
                          ),
                        ),
                      ),
                      Visibility(
                        visible: contentType == "application",
                        child: Align(
                          alignment: Alignment.center,
                          child: SizedBox(
                            height: 30,
                            width: 30,
                            child: Image(
                              image: AssetImage(
                                mediaType == "pdf"
                                    ? 'assets/appimages/pdf.png'
                                    : 'assets/appimages/excel.png',
                              ),
                              fit: BoxFit.cover,
                            ),
                          ),
                        ),
                      ),
                    ],
                  ),
            Visibility(
              visible: isUploading == 1,
              child: Center(
                child: Container(
                    margin: const EdgeInsets.all(8),
                    child: CircularProgressIndicator()),
              ),
            ),
            Visibility(
              visible: (contentType != null && contentType.contains("video")),
              child: Align(
                alignment: Alignment.center,
                child: Opacity(
                    opacity: 0.4,
                    child: GestureDetector(
                        behavior: HitTestBehavior.translucent,
                        onTap: () {
                          Navigator.of(context).push(MaterialPageRoute(
                              builder: (context) => ImageVideoFullPage(
                                  ownerId: widget.userId,
                                  ownerType: "person",
                                  mediaList: mediaList,
                                  isLocalFile: isUploading == 1 ? true : false,
                                  isWithOutData: true,
                                  isMediaPage: true,
                                  pageNumber: widget.pageNumber,
                                  position: 0,
                                  totalItems: 1)));
                        },
                        child: Container(
                            decoration: BoxDecoration(
                                color: HexColor(AppColors.appColorBlack),
                                shape: BoxShape.circle),
                            margin: const EdgeInsets.all(8),
                            child: Container(
                              padding: const EdgeInsets.all(4),
                              child: Icon(Icons.play_circle_outlined,
                                  color: HexColor(AppColors.appColorWhite)),
                            )))),
              ),
            )
          ],
        ),
      ),
    );
  }

  Widget popItem(Widget item, HelpDeskChatMessage data, String name) {
    if (data.contentType != null && data.contentType == 'json') {
      return item;
    } else {
      return PopupMenuButton<String>(
          onSelected: (String value) {
            if (value == "translate") {
              translate();
            } else
              widget.handleClickedOption(value, data, name);
          },
          child: item,
          itemBuilder: (context) => [
                PopupMenuItem(
                    value: "translate",
                    child: Row(
                      children: <Widget>[
                        Padding(
                          padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                          child: Icon(Icons.translate),
                        ),
                        Text(LeadsLocalizations.of(context)!
                            .translate('translate')),
                      ],
                    )),
                PopupMenuItem(
                    value: "Reply",
                    child: Row(
                      children: <Widget>[
                        Padding(
                          padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                          child: Icon(Icons.reply),
                        ),
                        Text(LeadsLocalizations.of(context)!.translate('reply')),
                      ],
                    )),
                // PopupMenuItem(
                //     value: "Forward",
                //     child: Row(
                //       children: <Widget>[
                //         Padding(
                //           padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                //           child: Icon(Icons.forward),
                //         ),
                //         Text(AppLocalizations.of(context)!.translate("forward"))
                //       ],
                //     )),
                PopupMenuItem(
                    value: "Copy",
                    child: Row(
                      children: <Widget>[
                        Padding(
                          padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                          child: Icon(Icons.copy_outlined),
                        ),
                        Text(LeadsLocalizations.of(context)!.translate("copy"))
                      ],
                    )),
                // PopupMenuItem(
                //     value: "Delete",
                //     child: Row(
                //       children: <Widget>[
                //         Padding(
                //           padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                //           child: Icon(Icons.delete_outline),
                //         ),
                //         Text(AppLocalizations.of(context)!.translate("delete"))
                //       ],
                //     )),
              ]);
    }
  }
}
