import 'package:flutter/material.dart';
import 'package:lead_management/presentation/pages/select_product_page.dart';

import '../utils/text_styling.dart';

enum ProductBottomSheetType { brand, category, product, catalogue }

class CommonManageProductSheets extends StatelessWidget {
  final String title;
  final Function(String) callback;
  final ProductBottomSheetType type;
  final ProductBrandCategoryCatalogueType fromType;
  late TextStyleElements styleElements;
  late BuildContext ctx;

  CommonManageProductSheets(
      {required this.title,
      required this.callback,
      required this.type,
      required this.fromType});

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    ctx = context;
    return Container(
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Padding(
            padding: const EdgeInsets.symmetric(vertical: 16.0),
            child: Text(
              title,
              style: styleElements
                  .subtitle1ThemeScalable(context)
                  .copyWith(fontWeight: FontWeight.bold),
            ),
          ),
          Column(
            mainAxisSize: MainAxisSize.min,
            children: _listofOptions(),
          ),
          const SizedBox(
            height: 80,
          )
        ],
      ),
    );
  }

  List<Widget> _listofOptions() {
    if (type == ProductBottomSheetType.brand) {
      return _brandOptions();
    } else if (type == ProductBottomSheetType.product) {
      return _productOptions();
    } else if (type == ProductBottomSheetType.catalogue) {
      return _cataloguesOptions();
    } else if (type == ProductBottomSheetType.category) {
      return _categoryOptions();
    } else {
      return [];
    }
  }

  List<Widget> _brandOptions() {
    return [
      ListTile(
          onTap: () {
            callback('brand_info');
          },
          leading: const Icon(Icons.info_outline_rounded),
          title: Text(
            "Brand info",
            style: styleElements.subtitle1ThemeScalable(ctx),
          )),
      ListTile(
          onTap: () {
            callback('edit_brand');
          },
          leading: const Icon(Icons.edit_outlined),
          title: Text(
            "Edit Brand",
            style: styleElements.subtitle1ThemeScalable(ctx),
          )),
      ListTile(
          onTap: () {
            callback('deactivate_brand');
          },
          leading: const Icon(Icons.toggle_off_outlined),
          title: Text(
            "Deactivate Brand",
            style: styleElements.subtitle1ThemeScalable(ctx),
          ))
    ];
  }

  List<Widget> _productOptions() {
    return [
      ListTile(
          onTap: () {
            callback('product_info');
          },
          leading: const Icon(Icons.info_outline_rounded),
          title: Text(
            "Product info",
            style: styleElements.subtitle1ThemeScalable(ctx),
          )),
      ListTile(
          onTap: () {
            callback('edit_product');
          },
          leading: const Icon(Icons.edit_outlined),
          title: Text(
            "Edit Product",
            style: styleElements.subtitle1ThemeScalable(ctx),
          )),
      ListTile(
          onTap: () {
            callback('deactivate_product');
          },
          leading: const Icon(Icons.toggle_off_outlined),
          title: Text(
            "Deactivate Product",
            style: styleElements.subtitle1ThemeScalable(ctx),
          )),
      if (fromType == ProductBrandCategoryCatalogueType.brand)
        ListTile(
            onTap: () {
              callback('deactivate_product');
            },
            leading: const Icon(Icons.cancel_outlined),
            title: Text(
              "Remove from this brand",
              style: styleElements.subtitle1ThemeScalable(ctx),
            )),
      if (fromType == ProductBrandCategoryCatalogueType.catalogue)
        ListTile(
            onTap: () {
              callback('deactivate_product');
            },
            leading: const Icon(Icons.cancel_outlined),
            title: Text(
              "Remove from this catalogue",
              style: styleElements.subtitle1ThemeScalable(ctx),
            )),
      if (fromType == ProductBrandCategoryCatalogueType.category)
        ListTile(
            onTap: () {
              callback('deactivate_product');
            },
            leading: const Icon(Icons.cancel_outlined),
            title: Text(
              "Remove from this category",
              style: styleElements.subtitle1ThemeScalable(ctx),
            ))
    ];
  }

  List<Widget> _cataloguesOptions() {
    return [
      ListTile(
          onTap: () {
            callback('catalogue_info');
          },
          leading: const Icon(Icons.info_outline_rounded),
          title: Text(
            "Catalogue info",
            style: styleElements.subtitle1ThemeScalable(ctx),
          )),
      ListTile(
          onTap: () {
            callback('edit_catalogue');
          },
          leading: const Icon(Icons.edit_outlined),
          title: Text(
            "Edit Catalogue",
            style: styleElements.subtitle1ThemeScalable(ctx),
          )),
      ListTile(
          onTap: () {
            callback('disable_catalogue');
          },
          leading: const Icon(Icons.toggle_off_outlined),
          title: Text(
            "Disable Catalogue",
            style: styleElements.subtitle1ThemeScalable(ctx),
          ))
    ];
  }

  List<Widget> _categoryOptions() {
    return [
      ListTile(
          onTap: () {
            callback('category_info');
          },
          leading: const Icon(Icons.info_outline_rounded),
          title: Text(
            "Category info",
            style: styleElements.subtitle1ThemeScalable(ctx),
          )),
      ListTile(
          onTap: () {
            callback('edit_category');
          },
          leading: const Icon(Icons.edit_outlined),
          title: Text(
            "Edit Category",
            style: styleElements.subtitle1ThemeScalable(ctx),
          )),
      ListTile(
          onTap: () {
            callback('disable_category');
          },
          leading: const Icon(Icons.toggle_off_outlined),
          title: Text(
            "Disable Category",
            style: styleElements.subtitle1ThemeScalable(ctx),
          ))
    ];
  }
}
