import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'package:timeago/timeago.dart' as timeago;
import 'package:flutter/material.dart';
import 'package:flutter_linkify/flutter_linkify.dart';

import 'package:intl/intl.dart';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:url_launcher/url_launcher.dart';

import '../../data/models/hepdesk_chat_message.dart';
import '../../data/models/postlist.dart';
import '../common_widgets/app_chat_footer.dart';
import '../common_widgets/audio_widget.dart';
import '../common_widgets/bubble_type.dart';
import '../common_widgets/chat_bubble.dart';
import '../common_widgets/chat_bubble_clipper_2.dart';
import '../common_widgets/custom_preview_link.dart';
import '../common_widgets/helpdesk_appbar.dart';
import '../common_widgets/imgevideoFullScreenViewPage.dart';
import '../common_widgets/manage_leads_screen.dart';
import '../common_widgets/receiver_message_helpdesk_widget.dart';
import '../common_widgets/update_status.dart';
import '../utils/appemptywidget.dart';
import '../utils/basicInfo.dart';
import '../utils/colors.dart';
import '../utils/commonComponents.dart';
import '../utils/hexColors.dart';
import '../utils/localization.dart';
import '../utils/resolutionenums.dart';
import '../utils/serviceTypeEnums.dart';
import '../utils/text_styling.dart';
import '../utils/utility_class.dart';

class HelpDeskChatScreen extends StatefulWidget {
  final Null Function()? callBack;
  final String? userStatus;
  final Null Function()? callBackNew;
  final Null Function()? refreshList;
  final Null Function()? homePageUnreadCount;
  final bool? isHeaderVisible;
  final String? type;
  final String? personId;
  final bool? isVisible;
  final int? ticketMainId;
  final bool? removeStack;

  @override
  HelpDeskChatScreenState createState() => HelpDeskChatScreenState(
        callBack: callBack,
        userStatus: userStatus,
        callBackNew: callBackNew,
        refreshList: refreshList,
        ticketMainId: ticketMainId,
        homePageUnreadCount: homePageUnreadCount,
        type: type,
        personId: personId,
      );

  HelpDeskChatScreen(
      {required Key? key,
      this.removeStack = false,
      this.personId,
      this.type,
      this.ticketMainId,
      this.callBack,
      this.refreshList,
      this.callBackNew,
      this.userStatus,
      this.homePageUnreadCount,
      this.isVisible,
      this.isHeaderVisible = true})
      : super(key: key);
}

class HelpDeskChatScreenState extends State<HelpDeskChatScreen>
    with WidgetsBindingObserver {
  Null Function()? callBack;
  BasicInfo? basicInfo = BasicInfo();
  int? userId = 0;
  String? personId="0";
  String? type;
  int? allRoomsId;
  int? eventId;
  BuildContext? ctx;
  Null Function()? refreshList;

  String? todayDate;
  Null Function()? callBackNew;
  bool? isNewConversation = false;
  String? userName;
  bool? isRequestApiCalled = false;
  int? callNumber = 0;
  bool? isUserOnCurrentPage = true;

  String? conversationWithId;
  String conversationWithType = "person";
  int? ticketMainId;
  String? mcId;

  SharedPreferences? prefs;
  String? status = "";
  String? userStatus;
  bool? isOnline = false;
  bool? isLoading = false;

  Null Function()? homePageUnreadCount;
  String? myConversationId;
  bool? isGroupConversation = false;
  bool? isRoomAvailable = false;
  String? imageUrl = "";

  String? conversationWithName = "";
  int? pageNumber = 1;
  bool? isAlreadySent = false;
  bool? isReply = false;
  bool? isSearch = false;
  String? date = "";
  String? linkPreview;
  GlobalKey<appChatFooterState>? chatFooterKey = GlobalKey();
  final commentController = TextEditingController();

  bool? isVisible;
  Iterable<RegExpMatch>? matches;
  File? pickedFile;
  String? conversationOwnerId;
  String? conversationOwnerType;
  String? outPutLan;

  File? outputFile;
  List<HelpDeskChatMessage> list = [];

  HelpDeskChatScreenState({
    this.callBack,
    this.userStatus,
    this.ticketMainId,
    this.callBackNew,
    this.refreshList,
    this.homePageUnreadCount,
    this.type,
    this.personId,
  });

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    switch (state) {
      case AppLifecycleState.resumed:
        break;
      case AppLifecycleState.inactive:
        // widget is inactive
        break;
      case AppLifecycleState.paused:
        // widget is paused
        break;
      case AppLifecycleState.detached:
        // widget is detached
        break;
    }
  }

  @override
  void initState() {
    status = userStatus;
    isUserOnCurrentPage = true;
    isVisible = widget.isVisible;
    RoomAvailableUpdate();

    WidgetsBinding.instance!.addObserver(this);
    WidgetsBinding.instance!.addPostFrameCallback((_) => setPref());
    todayDate = DateFormat('yyyy-MM-dd').format(DateTime.now());

    list.add(HelpDeskChatMessage(
        id: 0,
        isFailed: 0,
        title: "Welcome",
        createdAt: 0,
        isUploading: 0,
        personId: 0,
        ticketMainId: 647,
        contentType: null,
        content:
            "Welcome to conversational lead form. Please follow the instructions carefully and fill all required details.",
        mediaType: null,
        mediaUrl: null,
        mediaMimeType: null,
        isReply: null,
        originalCommentId: null,
        originalCommentContent: null,
        originalCommentContentType: null,
        originalCommentMediaType: null,
        originalCommentMediaUrl: null,
        originalCommentMediaMimeType: null,
        commentStatus: null,
        applicableTo: null));
    super.initState();
    updateReadStatus();
  }

  void RoomAvailableUpdate() {
    if (!isRoomAvailable!) {
      isRoomAvailable = true;
    }
  }

  Widget popItem(
      Widget item, HelpDeskChatMessage data, String name, bool isReceiver) {
    return PopupMenuButton<String>(
        onSelected: (String value) {
          handleClickedOption(value, data, name);
        },
        child: item,
        itemBuilder: (context) => [
              PopupMenuItem(
                  value: "Reply",
                  child: Row(
                    children: <Widget>[
                      const Padding(
                        padding: EdgeInsets.fromLTRB(2, 2, 8, 2),
                        child: Icon(Icons.reply),
                      ),
                      Text(LeadsLocalizations.of(context)!.translate('reply')),
                    ],
                  )),

              /*    PopupMenuItem(
                  value: "Rate content",
                  child: Row(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                        child: Icon(Icons.star_outline),
                      ),
                      Text(AppLocalizations.of(context)
                          .translate("rate_content"))
                    ],
                  )),
              PopupMenuItem(
                  value: "Book mark",
                  child: Row(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                        child: Icon(Icons.star_outline),
                      ),
                      Text(AppLocalizations.of(context).translate("bookmark"))
                    ],
                  )),*/
              PopupMenuItem(
                  value: "Copy",
                  child: Row(
                    children: <Widget>[
                      Padding(
                        padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
                        child: Icon(Icons.copy_outlined),
                      ),
                      Text(LeadsLocalizations.of(context)!.translate("copy"))
                    ],
                  )),
              // PopupMenuItem(
              //     value: "Delete",
              //     child: Row(
              //       children: <Widget>[
              //         Padding(
              //           padding: const EdgeInsets.fromLTRB(2, 2, 8, 2),
              //           child: Icon(Icons.delete_outline),
              //         ),
              //         Text(AppLocalizations.of(context)!.translate("delete"))
              //       ],
              //     )),
            ]);
  }

  getReceiverView(dynamic item, CustomClipper<Path> clipper,
      BuildContext context, int index) {
    var textPreview;
    if (item.content != null) {
      RegExp exp = RegExp(
          r'https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&//=]*)');
      Iterable<RegExpMatch> matches = exp.allMatches(item.content);
      if (matches.isNotEmpty) {
        matches.forEach((match) {
          textPreview = item.contentType != null && item.contentType == "object"
              ? jsonDecode(item.content)['content']
                  .substring(match.start, match.end)
              : item.content.substring(match.start, match.end);
        });
      }
    }
    return ChatBubble(
      clipper: clipper,
      backGroundColor: HexColor(AppColors.appColorWhite),
      margin: EdgeInsets.only(top: 20),
      elevation: 1,
      child: Padding(
        padding: const EdgeInsets.only(left: 8.0, right: 8.0),
        child: Container(
          constraints: BoxConstraints(
            maxWidth: MediaQuery.of(context).size.width * 0.7,
          ),
          child: Container(
              child: ReceiverWidgetHelpdesk(
            ratingGiven: "0",
            outPutLan: outPutLan,
            responsiblePersonId: 0,
            conversationWithName: conversationWithName ?? "",
            handleClickedOption:
                (String value, HelpDeskChatMessage data, String name) {
              handleClickedOption(value, data, name);
            },
            item: item,
            userId: userId!,
            isGroupConversation: isGroupConversation!,
            textPreview: textPreview ?? "",
            pageNumber: pageNumber!,
            clipper: clipper,
          )),
        ),
      ),
    );
  }

  handleClickedOption(
      String value, HelpDeskChatMessage data, String name) async {
    switch (value) {
      case "Reply":
        {
          /* isReply = true;
          replyData = data;
          chatFooterKey!.currentState!.helpDeskChatMessage = data;
          chatFooterKey!.currentState!.userName = name;
          if (this.mounted) setState(() {});*/
        }
        break;

      case "translate":
        {
          /*   receiverMessageItemState.currentState!.translate();*/
        }
        break;
      case "Copy":
        {
          /*  Clipboard.setData(new ClipboardData(text: data.content));
          ToastBuilder()
              .showToast("Copied", ctx, HexColor(AppColors.information));*/
        }
        break;
      case "Delete":
        {
          break;
        }
    }
  }

  getSenderView(HelpDeskChatMessage item, ChatBubbleClipper2 clipper,
      BuildContext context, int index) {
    var textPreview;
    if (item.content != null) {
      RegExp exp = RegExp(
          r'https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&//=]*)');
      Iterable<RegExpMatch> matches = exp.allMatches(item.content!);

      if (matches.isNotEmpty) {
        matches.forEach((match) {
          textPreview = item.contentType != null && item.contentType == "object"
              ? jsonDecode(item.content!)['message']
                  .substring(match.start, match.end)
              : item.content!.substring(match.start, match.end);
        });
      }
    }

    getMediaView(String? mediaUrl, String? mediaType, String? contentType,
        int? isUploading, HelpDeskChatMessage item, int isReply) {
      List<Media> mediaList = [];
      mediaList
          .add(Media(mediaUrl: mediaUrl ?? "", mediaType: mediaType ?? ""));
      return isReply == 0 && item.mediaType == "audio" ||
              isReply == 1 && item.originalCommentMediaType == "audio"
          ? AudioWidget(
              url: basicInfo!.baseUrl +
                  (isReply == 1
                      ? item.originalCommentMediaUrl ?? ""
                      : item.mediaUrl ?? ""))
          : GestureDetector(
              behavior: HitTestBehavior.translucent,
              onTap: () {
                if (mediaType == "image" || mediaType == "video") {
                  Navigator.of(ctx!).push(MaterialPageRoute(
                      builder: (context) => ImageVideoFullPage(
                          ownerId: userId,
                          ownerType: "person",
                          mediaList: mediaList,
                          isWithOutData: true,
                          isLocalFile: isUploading == 1 ? true : false,
                          isMediaPage: true,
                          pageNumber: pageNumber,
                          position: 0,
                          totalItems: 1)));
                } else {
                  launch(basicInfo!.baseUrl + mediaUrl!);
                }
              },
              child: Container(
                padding: const EdgeInsets.all(4.0),
                height: 200,
                width: 200,
                child: Stack(
                  children: [
                    isUploading == 1
                        ? SizedBox(
                            height: 200,
                            width: 200,
                            child: mediaType == "image" || mediaType == "video"
                                ? new Image.file(
                                    mediaType == "image"
                                        ? File(mediaUrl ?? "")
                                        : File(mediaUrl ?? ""),
                                    fit: BoxFit.cover,
                                  )
                                : SizedBox(
                                    height: 200,
                                    width: 200,
                                    child: Image(
                                      image: AssetImage(
                                        mediaType == "pdf"
                                            ? 'assets/appimages/pdf.png'
                                            : 'assets/appimages/excel.png',
                                      ),
                                      fit: BoxFit.cover,
                                    ),
                                  ),
                          )
                        : Stack(
                            children: [
                              Container(
                                decoration: BoxDecoration(
                                  image: DecorationImage(
                                    image: mediaType == "image"
                                        ? NetworkImage(
                                            Utility().getUrlForImage(
                                                (mediaUrl ?? ""),
                                                RESOLUTION_TYPE.R256,
                                                SERVICE_TYPE.PERSON),
                                          )
                                        : NetworkImage(Utility().getUrlForImage(
                                            (mediaUrl ?? ""),
                                            RESOLUTION_TYPE.R256,
                                            SERVICE_TYPE.PERSON)),
                                    fit: BoxFit.cover,
                                  ),
                                ),
                              ),
                              Visibility(
                                visible: mediaType == "application",
                                child: Align(
                                  alignment: Alignment.center,
                                  child: SizedBox(
                                    height: 30,
                                    width: 30,
                                    child: Image(
                                      image: AssetImage(
                                        mediaType == "pdf"
                                            ? 'assets/appimages/pdf.png'
                                            : 'assets/appimages/excel.png',
                                      ),
                                      fit: BoxFit.cover,
                                    ),
                                  ),
                                ),
                              ),
                            ],
                          ),
                    Visibility(
                      visible: isUploading == 1,
                      child: Center(
                        child: Container(
                            margin: const EdgeInsets.all(8),
                            child: CircularProgressIndicator()),
                      ),
                    ),
                    Visibility(
                      visible:
                          (mediaType != null && mediaType.contains("video")),
                      child: Align(
                        alignment: Alignment.center,
                        child: Opacity(
                            opacity: 0.4,
                            child: GestureDetector(
                                behavior: HitTestBehavior.translucent,
                                onTap: () {
                                  Navigator.of(ctx!).push(MaterialPageRoute(
                                      builder: (context) => ImageVideoFullPage(
                                          ownerId: userId,
                                          ownerType: "person",
                                          mediaList: mediaList,
                                          isLocalFile:
                                              isUploading == 1 ? true : false,
                                          isWithOutData: true,
                                          isMediaPage: true,
                                          pageNumber: pageNumber,
                                          position: 0,
                                          totalItems: 1)));
                                },
                                child: Container(
                                    decoration: BoxDecoration(
                                        color:
                                            HexColor(AppColors.appColorBlack),
                                        shape: BoxShape.circle),
                                    margin: const EdgeInsets.all(8),
                                    child: Container(
                                      padding: const EdgeInsets.all(4),
                                      child: Icon(Icons.play_circle_outlined,
                                          color: HexColor(
                                              AppColors.appColorWhite)),
                                    )))),
                      ),
                    )
                  ],
                ),
              ),
            );
    }

    return ChatBubble(
      clipper: clipper,
      backGroundColor: HexColor(AppColors.blue_chat),
      margin: EdgeInsets.only(top: 16),
      elevation: 1,
      shadowColor: HexColor(AppColors.appColorBlack35),
      alignment: Alignment.center,
      child: Padding(
        padding: const EdgeInsets.only(left: 16.0, right: 16.0),
        child: Container(
          constraints: BoxConstraints(
            maxWidth: MediaQuery.of(context).size.width * 0.7,
          ),
          child: Column(
            children: [
              Visibility(
                visible: textPreview != null,
                child: CustomPreviewLink(
                    context, textPreview ?? "", styleElements),
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.end,
                mainAxisSize: MainAxisSize.min,
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  Visibility(
                    visible: item.title != null,
                    child: Text(item.title ?? "",
                        style: styleElements.subtitle2ThemeScalable(context).copyWith(color: HexColor(AppColors.appColorWhite))),
                  ),
                  Visibility(
                    visible: item.isReply != null && item.isReply == 1,
                    child: Container(
                      decoration: BoxDecoration(
                          color: HexColor(AppColors.white_translucent),
                          border: Border.all(
                            color: HexColor(AppColors.white_translucent),
                          ),
                          borderRadius: BorderRadius.all(Radius.circular(8))),
                      child: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Column(
                          mainAxisAlignment: MainAxisAlignment.start,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Visibility(
                              visible: item.originalCommentMediaUrl != null &&
                                  item.originalCommentMediaUrl != "",
                              child: getMediaView(
                                  item.originalCommentMediaUrl,
                                  item.originalCommentMediaType,
                                  item.originalCommentContentType,
                                  0,
                                  item,
                                  1),
                            ),
                            Linkify(
                              onOpen: (link) async {
                                if (await canLaunch(link.url)) {
                                  await launch(link.url);
                                } else {
                                  throw 'error';
                                }
                              },
                              text: item.originalCommentContent ?? "",
                              style:
                                  styleElements.subtitle1ThemeScalable(context),
                              linkStyle: TextStyle(
                                  color: HexColor(AppColors.appMainColor)),
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),
                  Visibility(
                    visible: item.mediaUrl != null && item.mediaUrl != "",
                    child: getMediaView(item.mediaUrl, item.mediaType,
                        item.contentType, item.isUploading, item, 0),
                  ),
                  Flexible(
                    child: Container(
                      width: item.mediaUrl != null && item.mediaUrl != ""
                          ? 200
                          : null,
                      alignment: item.mediaUrl != null && item.mediaUrl != ""
                          ? Alignment.topRight
                          : null,
                      child: Linkify(
                        onOpen: (link) async {
                          if (await canLaunch(link.url)) {
                            await launch(link.url);
                          } else {
                            throw 'error';
                          }
                        },
                        text: item.contentType != null &&
                                item.contentType == "object"
                            ? jsonDecode(item.content!)['message'] ?? ""
                            : item.content ?? "",
                        style: styleElements.subtitle1ThemeScalable(context).copyWith(color: HexColor(AppColors.appColorWhite)),
                        maxLines: item.mediaUrl != null && item.mediaUrl != ""
                            ? 2
                            : null,
                        linkStyle:
                            TextStyle(color: HexColor(AppColors.appColorWhite)),
                      ),
                    ),
                  ),
                  Row(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Text(
                        timeago.format(DateTime.fromMillisecondsSinceEpoch(
                            item.createdAt!)),
                        style: styleElements
                            .captionThemeScalable(context)
                            .copyWith(
                                color: HexColor(AppColors.appColorWhite)),
                      ),
                    ],
                  )
                ],
              ),
            ],
          ),
        ),
      ),
    );
  }

  Widget listItemBuilder(value, int index) {
    HelpDeskChatMessage item = value;
    if (item.contentType != null &&
        item.contentType == 'json' &&
        HelpdeskMessageContent.fromJson(jsonDecode(item.content!)).cardType ==
            "status") {
      return SizedBox.shrink();
    } else {
      if (item.contentType == 'text' &&
          (item.personId == null || item.personId == 0)) {
        return Padding(
          padding:
              const EdgeInsets.only(left: 20.0, right: 20.0, top: 8, bottom: 8),
          child: Container(
              child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            mainAxisSize: MainAxisSize.min,
            children: [
              Flexible(
                child: Container(
                  padding: EdgeInsets.all(8),
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(12),
                      color: HexColor(AppColors.appColorGrey100),
                      boxShadow: [CommonComponents().getShadowforBox_01_3()]),
                  child: Text(
                    item.content ?? "",
                    textAlign: TextAlign.center,
                    style: styleElements
                        .bodyText2ThemeScalable(ctx!)
                        .copyWith(fontSize: 14),
                  ),
                ),
              ),
            ],
          )),
        );
      } else {
        return item.personId == 0 || item.contentType == 'json'
            ? Padding(
                padding: const EdgeInsets.only(left: 8.0, right: 8.0),
                child: Container(
                    child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    getReceiverView(
                        item,
                        ChatBubbleClipper2(type: BubbleType.receiverBubble),
                        ctx!,
                        index),
                  ],
                )),
              )
            : Padding(
                padding: const EdgeInsets.only(left: 8.0, right: 8.0),
                child: GestureDetector(
                  behavior: HitTestBehavior.translucent,
                  onTap: () async {
                    /*await db.dlt();*/
                  },
                  child: Container(
                      child: Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      popItem(
                          getSenderView(
                              item,
                              ChatBubbleClipper2(type: BubbleType.sendBubble),
                              ctx!,
                              index),
                          item,
                          userName ?? "-",
                          false),
                    ],
                  )),
                ),
              );
      }
    }
  }

  @override
  void dispose() {
    WidgetsBinding.instance!.removeObserver(this);

    super.dispose();
  }

  void updateReadStatus() {}

  Future<void> setPref() async {}
  late TextStyleElements styleElements;

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    ctx = this.context;
    return WillPopScope(
        // ignore: missing_return
        onWillPop: () async {
          return true;
        },
        child: SafeArea(
          child: Scaffold(
              backgroundColor: HexColor(AppColors.chatBackGround),
              appBar: widget.isHeaderVisible!
                  ? HelpDeskAppBar(
                      isPicked: true,
                      ticketId: 1283679,
                      issueType: "Marketing",
                      dueDays: "Due in 12 Hrs",
                      priority: "High",
                      ticketStatus: "Unassigned",
                      isNotificationVisible: false,
                      roomId: 197893,
                      roomName: "Lava International",
                      currentStatusName: "New",
                      priorityColor: AppColors.appNotificationColor,
                      showCallbuttons: !isGroupConversation!,
                      agentName: "Desi",
                      agentAvatar: "",
                      agentId: 12344,
                      onMoreClick: () {
                        FocusScopeNode currentFocus = FocusScope.of(context);
                        if (!currentFocus.hasPrimaryFocus) {
                          currentFocus.unfocus();
                        }
                      },
                      onVideoCallback: () {},
                      onCallCallback: () {},
                      priorityCallBack: () {
                        _manageLeads();
                      },
                      statusCallBack: () {
                        _showUpdateStatusSheet();
                      },
                      callBack: () {
                        if (isSearch! && mounted) {
                          setState(() {});
                        } else {
                          if (mounted) {
                            setState(() {
                              isUserOnCurrentPage = false;
                            });
                          }

                          Navigator.of(context).pop();
                          if (homePageUnreadCount != null)
                            homePageUnreadCount!();
                        }
                      },
                      isSearch: isSearch,
                      onSearch: (String value) {},
                      onItemSelect: (String value) {},
                      imageUrl: "",
                      title: "Lava International",
                      status: "Distributor",
                      isGroupConversation: isGroupConversation,
                      userType: 'person',
                      userId: 0,
                      notificationCount: 0,
                      agentListCallback: () {},
                    )
                  : null,
              body: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: [
                  Expanded(
                      child: list.isNotEmpty
                          ? Container(
                              child: NotificationListener<ScrollNotification>(
                                onNotification:
                                    (ScrollNotification scrollInfo) {
                                  if (scrollInfo is ScrollEndNotification &&
                                      scrollInfo.metrics.extentAfter == 0) {
                                    return true;
                                  }
                                  return false;
                                },
                                child: ListView.builder(
                                    reverse: true,

                                    physics:
                                        const AlwaysScrollableScrollPhysics(),
                                    padding: EdgeInsets.only(
                                        left: 8, right: 8, bottom: 4, top: 8),
                                    itemCount: list.length,
                                    cacheExtent: 5,
                                    itemBuilder:
                                        (BuildContext context, int index) {
                                      return listItemBuilder(
                                          List.from(list.reversed)[index], index);
                                    }),
                              ),
                            )
                          : ListView.builder(
                              physics: const AlwaysScrollableScrollPhysics(),
                              itemCount: 1,
                              itemBuilder: (BuildContext context, int index) {
                                return Center(
                                    child: Padding(
                                  padding: const EdgeInsets.all(20.0),
                                  child: appEmptyWidget(
                                    message: LeadsLocalizations.of(context)!
                                        .translate('no_messages'),
                                  ),
                                )
                                    // EmptyWidget(AppLocalizations.of(context)
                                    //     .translate('no_data'),

                                    );
                              })),
                  Align(
                    alignment: Alignment.bottomCenter,
                    child: appChatFooter(
                      chatFooterKey!,
                      hintText: "Mr. ",
                      linkPreviewUrl: linkPreview,
                      isEmptyTextAccepted: false,
                      audioEvent: (bool isRecorde) {},
                      userName: conversationWithName,
                      onCrossCLicked: () {},
                      isShowAddIcon: true,
                      onTyping: (String v) async {},
                      onValueRecieved: (value) async {
                        if(value=="0") {
                          list.add(HelpDeskChatMessage(
                              id: 0,
                              isFailed: 0,
                              title: "Name",
                              createdAt: 0,
                              isUploading: 0,
                              personId: 2,
                              ticketMainId: 647,
                              contentType: null,
                              content: "Savil Mehra",
                              mediaType: null,
                              mediaUrl: null,
                              mediaMimeType: null,
                              isReply: null,
                              originalCommentId: null,
                              originalCommentContent: null,
                              originalCommentContentType: null,
                              originalCommentMediaType: null,
                              originalCommentMediaUrl: null,
                              originalCommentMediaMimeType: null,
                              commentStatus: null,
                              applicableTo: null));
                        }
                        if(value=="1") {
                          list.add(HelpDeskChatMessage(
                              id: 0,
                              isFailed: 0,
                              title: "Phone",
                              createdAt: 0,
                              isUploading: 0,
                              personId: 2,
                              ticketMainId: 647,
                              contentType: null,
                              content: "+91 95234578097",
                              mediaType: null,
                              mediaUrl: null,
                              mediaMimeType: null,
                              isReply: null,
                              originalCommentId: null,
                              originalCommentContent: null,
                              originalCommentContentType: null,
                              originalCommentMediaType: null,
                              originalCommentMediaUrl: null,
                              originalCommentMediaMimeType: null,
                              commentStatus: null,
                              applicableTo: null));
                        }
                        if(value=="2") {
                          list.add(HelpDeskChatMessage(
                              id: 0,
                              isFailed: 0,
                              title: "Email ID",
                              createdAt: 0,
                              isUploading: 0,
                              personId: 1,
                              ticketMainId: 647,
                              contentType: null,
                              content: "savksjysf@gmail.com",
                              mediaType: null,
                              mediaUrl: null,
                              mediaMimeType: null,
                              isReply: null,
                              originalCommentId: null,
                              originalCommentContent: null,
                              originalCommentContentType: null,
                              originalCommentMediaType: null,
                              originalCommentMediaUrl: null,
                              originalCommentMediaMimeType: null,
                              commentStatus: null,
                              applicableTo: null));
                        }
                        if(value=="3") {
                          list.add(HelpDeskChatMessage(
                              id: 0,
                              isFailed: 0,
                              title: "Business Name",
                              createdAt: 0,
                              isUploading: 0,
                              personId: 1,
                              ticketMainId: 647,
                              contentType: null,
                              content: "Airtel India Pvt. Ltd",
                              mediaType: null,
                              mediaUrl: null,
                              mediaMimeType: null,
                              isReply: null,
                              originalCommentId: null,
                              originalCommentContent: null,
                              originalCommentContentType: null,
                              originalCommentMediaType: null,
                              originalCommentMediaUrl: null,
                              originalCommentMediaMimeType: null,
                              commentStatus: null,
                              applicableTo: null));
                        }
                        setState(() {

                        });
                      },
                      onReceiveOption: (value, text) async {},
                    ),
                  )
                ],
              )),
        ));
  }

  void _showUpdateStatusSheet() {
    showModalBottomSheet(
      context: ctx!,
      shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(12), topRight: Radius.circular(12))),
      builder: (BuildContext context) {
        return UpdateStatusSheet(
          doneCallback: (value) {},
        );
      },
    );
  }

  void _manageLeads() {
    showModalBottomSheet(
      context: ctx!,
      shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(12), topRight: Radius.circular(12))),
      builder: (BuildContext context) {
        return ManageLeadsSheet(
          doneCallback: (value) {},
        );
      },
    );
  }
}
