import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/app_buttons.dart';
import 'package:lead_management/presentation/utils/colors.dart';
import 'package:lead_management/presentation/utils/custom_app_bar.dart';
import 'package:lead_management/presentation/utils/customcard.dart';
import 'package:lead_management/presentation/utils/hexColors.dart';
import 'package:lead_management/presentation/utils/text_styling.dart';

import '../../enums/ticket_list_type.dart';
import '../common_widgets/app_find_card.dart';
import '../common_widgets/customgridDelegate.dart';
import '../utils/basicInfo.dart';
import '../utils/searchBox.dart';
import 'lead_refrences_page.dart';
import 'leads_setting_page.dart';


class HelpdeskDashboard extends StatefulWidget {

  final String baseUrl;
  final int userId;
  final int businessId;
  final String token;
  final String currencySymbol;
  final String appLanguageCode;
  final String googleTranslationKey;
  final String userName;
  final String userImage;
  final String baseUrlWithoutHttp;
  final String timeFormat;
  final String dateFormat;
  final String mainColor;
  final String googleMapKey;
  final String slug;

  HelpdeskDashboard(
      {Key? key,
        required this.slug,
        required this.baseUrl,
        required this.googleMapKey,
        required this.mainColor,
        required this.currencySymbol,
        required this.userId,
        required this.appLanguageCode,
        required this.googleTranslationKey,
        required this.token,
        required this.businessId,
        required this.userName,
        required this.userImage,
        required this.baseUrlWithoutHttp,
        required this.timeFormat,
        required this.dateFormat})
      : super(key: key);
  @override
  HelpdeskDashboardState createState() => HelpdeskDashboardState();
}

class HelpdeskDashboardState extends State<HelpdeskDashboard> {

  String? date;
  BasicInfo? basicInfo = BasicInfo();
  int startTime = DateTime(1900).millisecondsSinceEpoch;
  int endTime = DateTime.now().millisecondsSinceEpoch;
  TextStyleElements? styleElements;
  @override
  void initState() {
    super.initState();
    setBasicData();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {

    });
  }

  setBasicData() async {
    basicInfo?.slug = widget.slug;
    basicInfo?.appLanguageCode = widget.appLanguageCode;
    basicInfo?.googleTransltionKey = widget.googleTranslationKey;
    basicInfo?.token = widget.token;
    basicInfo?.currencySymbol = widget.currencySymbol;
    basicInfo?.baseUrl = widget.baseUrl;
    basicInfo?.userId = widget.userId;
    basicInfo?.businessId = widget.businessId;
    basicInfo?.userName = widget.userName;
    basicInfo?.userImage = widget.userImage;
    basicInfo?.baseUrlWithoutHttp = widget.baseUrlWithoutHttp;
    basicInfo?.timeFormat = widget.timeFormat;
    basicInfo?.dateFormat = widget.dateFormat;
    basicInfo?.googleMapKey = widget.googleMapKey;
    AppColors.appMainColor = widget.mainColor;

    setState(() {});
  }
  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        appBar: appAppBar().getCustomAppBar(
          context,
          actions: [IconButton(onPressed: (){}, icon: Icon(Icons.segment))],

          appBarTitle: "Lead Management",
          onBackButtonPress: () {
            Navigator.pop(context);
          },
        ),
        body: ListView(
          children: [


            appFindCard(
              title: 'Lead Management system',
              subtitle:
                  'You can track all queries & issues of your partners at one place',
              titleColor: HexColor(AppColors.appColorWhite),
              subtitleColor: HexColor(AppColors.appColorWhite),
              image: Container(
               /* child: Image.asset(
                  'assets/appimages/learningbanner.png',
                  fit: BoxFit.cover,
                  height: 180,
                  width: 200,
                ),*/
              ),
              color: HexColor(AppColors.appMainColor),
            ),
            Padding(
              padding: const EdgeInsets.only(
                  left: 8.0, top: 4, bottom: 4, right: 16),
              child: Row(
                children: [
                  Text(
                    'Total tickets',
                    style: styleElements!.subtitle1ThemeScalable(context),
                  ),
                  Spacer(),
                  appTextButton(
                      onPressed: () async {
                        var nowTime = DateTime.now();
                        var range = await showDateRangePicker(
                            context: context,
                            initialEntryMode: DatePickerEntryMode.calendarOnly,
                            firstDate: DateTime(nowTime.year - 3, nowTime.month,
                                nowTime.day, nowTime.hour, nowTime.minute),
                            lastDate: DateTime(nowTime.year + 3, nowTime.month,
                                nowTime.day, nowTime.hour, nowTime.minute),
                            saveText: "SELECT",
                            builder: (BuildContext context, Widget? child) {
                              return Theme(
                                data: ThemeData.light().copyWith(
                                  colorScheme: ColorScheme.light(
                                    primary: HexColor(AppColors.appMainColor),
                                    onPrimary:
                                        HexColor(AppColors.appColorWhite),
                                    surface: HexColor(AppColors.appColorWhite),
                                    onSurface: HexColor(AppColors.appMainColor),
                                  ),
                                  dialogBackgroundColor:
                                      HexColor(AppColors.appMainColor),
                                ),
                                child: child!,
                              );
                            });
                        if (range != null) {
                          startTime = range.start.millisecondsSinceEpoch;
                          endTime = range.end.millisecondsSinceEpoch;
                          setState(() {

                          });

                        }
                      },
                      child: Row(
                        mainAxisSize: MainAxisSize.min,
                        children: [
                          Text(date ?? 'Till today'),
                          Icon(Icons.arrow_drop_down)
                        ],
                      ))
                ],
              ),
            ),
            GridView(
              shrinkWrap: true,
              children: [
                HelpdeskDashboardDisplayWidget(
                  title: "Total leads",
                  subtitle:  "0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: null,
                      listType: TicketListType.ALL.type,
                    );
                  },
                ),
                HelpdeskDashboardDisplayWidget(
                  title: "Open",
                  subtitle: "0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.UNASSIGNED.type,
                      listType: TicketListType.ALL.type,
                    );
                  },
                ),
                HelpdeskDashboardDisplayWidget(
                  title: "Handling",
                  subtitle:  "0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.ASSIGNED_REOPEN.type,
                      listType: TicketListType.ALL.type,
                    );
                  },
                ),
                HelpdeskDashboardDisplayWidget(
                  title: "Resolved",
                  subtitle:"0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.ONHOLD.type,
                      listType: TicketListType.ALL.type,
                    );
                  },
                ),
                HelpdeskDashboardDisplayWidget(
                  title: "Close",
                  subtitle:"0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.RESOLVED.type,
                      listType: TicketListType.ALL.type,
                    );
                  },
                ),

                HelpdeskDashboardDisplayWidget(
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.CLOSED.type,
                      listType: TicketListType.ALL.type,
                      showOptions: false,
                      showRating: true,
                    );
                  },
                  title: "Rating",
                  subtitle:
                      "0.0",
                )
              ],
              physics: ClampingScrollPhysics(),
              gridDelegate:
                  SliverGridDelegateWithFixedCrossAxisCountAndFixedHeight(
                      crossAxisCount: 3, height: 80),
            ),
            Padding(
              padding: const EdgeInsets.only(left: 8.0, top: 12, bottom: 12),
              child: Text(
                'Your tickets',
                style: styleElements!.subtitle1ThemeScalable(context),
              ),
            ),
            GridView(
              shrinkWrap: true,
              physics: ClampingScrollPhysics(),
              children: [
                HelpdeskDashboardDisplayWidget(
                  title: "Total tickets",
                  subtitle:  "0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: null,
                      listType: TicketListType.MY.type,
                    );
                  },
                ),
                HelpdeskDashboardDisplayWidget(
                  title: "Picked",
                  subtitle: "0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.ASSIGNED_REOPEN.type,
                      listType: TicketListType.MY.type,
                    );
                  },
                ),
                HelpdeskDashboardDisplayWidget(
                  title: "Open",
                  subtitle:"0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.ONHOLD.type,
                      listType: TicketListType.MY.type,
                    );
                  },
                ),
                HelpdeskDashboardDisplayWidget(
                  title: "Resolved",
                  subtitle: "0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.RESOLVED.type,
                      listType: TicketListType.MY.type,
                    );
                  },
                ),
                HelpdeskDashboardDisplayWidget(
                  title: "Closed",
                  subtitle: "0",
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.CLOSED.type,
                      listType: TicketListType.MY.type,
                    );
                  },
                ),
                HelpdeskDashboardDisplayWidget(
                  onPressed: () {
                    openTicketListPage(
                      context,
                      isNewTicket: false,
                      status: TicketListStatus.CLOSED.type,
                      listType: TicketListType.MY.type,
                      showOptions: false,
                      showRating: true,
                    );
                  },
                  title: "Rating",
                  subtitle:
                    "0.0",
                )
              ],
              gridDelegate:
                  SliverGridDelegateWithFixedCrossAxisCountAndFixedHeight(
                      crossAxisCount: 3, height: 80),
            ),

              Padding(
                padding: const EdgeInsets.only(left: 8.0, top: 12, bottom: 12),
                child: Row(
                  children: [
                    Text(
                      'Settings',
                      style: styleElements!.subtitle1ThemeScalable(context),
                    ),
                  ],
                ),
              ),
            GridView(
              shrinkWrap: true,
              physics: ClampingScrollPhysics(),
              children: [

                  HelpdeskDashboardDisplayWidget(
                    onPressed: () {
                      Navigator.push(context,
                          MaterialPageRoute(builder: (BuildContext context) {
                        return LeadsSettingsPage();
                      }));
                    },
                    icon: Padding(
                      padding: EdgeInsets.only(left: 8.0, right: 8, top: 4),
                      child: Image.asset(
                         'packages/lead_management/assets/appimages/helpdesk-setting.png',
                        width: 24,
                        height: 24,
                      ),
                    ),
                    title: "Leads Settings",
                    subtitle: "Manage all leads settings",
                    isIconShow: true,
                  ),
                HelpdeskDashboardDisplayWidget(
                  onPressed: () {
              /*      Navigator.push(context,
                        MaterialPageRoute(builder: (BuildContext context) {
                          return HelpDeskTicketListPage(
                            listType: 'all',
                          );
                        }));*/
                  },
                  icon: Padding(
                    padding: EdgeInsets.only(left: 8.0, right: 8, top: 4),
                    child: Image.asset(
                      'packages/lead_management/assets/appimages/help.png',
                      width: 24,
                      height: 24,
                    ),
                  ),
                  title: "Leads documents",
                  subtitle: "Manage all documents",
                  isIconShow: true,
                ),
              ],
              gridDelegate:
                  SliverGridDelegateWithFixedCrossAxisCountAndFixedHeight(
                      crossAxisCount: 2, height: 90),
            ),
          ],
        ),
      ),
    );
  }

  void openTicketListPage(BuildContext context,
      {String? status,
      String? listType,
      bool isNewTicket = false,
      bool showOptions = true,
      bool showRating = false}) {
    Navigator.push(context, MaterialPageRoute(builder: (BuildContext context) {
      return LeadRefresncesPage(
      );
    }));
  }

  void refresh() {
  // fetchData(startTime, endTime);
  }
}

class HelpdeskDashboardDisplayWidget extends StatelessWidget {
  final String? title;
  final String? subtitle;
  final bool isIconShow;
  final Function? onPressed;
  final Widget? icon;

  HelpdeskDashboardDisplayWidget(
      {this.title,
      this.subtitle,
      this.isIconShow = false,
      this.onPressed,
      this.icon});

  @override
  Widget build(BuildContext context) {
    var styleElements = TextStyleElements(context);
    return appListCard(
      onTap: onPressed,
      padding: EdgeInsets.only(left: 8, bottom: 6, right: 8, top: 8),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Visibility(visible: isIconShow, child: icon ?? Container()),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  title ?? "",
                  style: isIconShow
                      ? styleElements.subtitle1ThemeScalable(context).copyWith(
                            fontWeight: FontWeight.bold,
                          )
                      : styleElements.bodyText2ThemeScalable(context),
                  maxLines: 1,
                  overflow: TextOverflow.ellipsis,
                ),
                isIconShow ? Container() : Spacer(),
                Row(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    if (!isIconShow) Spacer(),
                    if (isIconShow)
                      Flexible(
                        child: Text(
                          subtitle ?? "",
                          style: styleElements.bodyText2ThemeScalable(context),
                        ),
                      ),
                    if (!isIconShow)
                      Text(
                        subtitle ?? "",
                        style: styleElements
                            .subtitle1ThemeScalable(context)
                            .copyWith(
                              fontWeight: FontWeight.bold,
                            ),
                      ),
                  ],
                )
              ],
            ),
          ),
        ],
      ),
    );
  }
}
