
import 'package:flutter/material.dart';
import 'package:lead_management/presentation/utils/colors.dart';
import 'package:lead_management/presentation/utils/custom_app_bar.dart';
import 'package:lead_management/presentation/utils/customcard.dart';
import 'package:lead_management/presentation/utils/hexColors.dart';
import 'package:lead_management/presentation/utils/text_styling.dart';

import '../common_widgets/Circular_Avtar.dart';
import '../common_widgets/common_sheet_with_two_text_fields.dart';
import '../common_widgets/edit_lead_status_sheet.dart';
import '../utils/common_helpdesk_sheet.dart';
import '../utils/localization.dart';

class ManageLeadStatusPage extends StatefulWidget {
  @override
  ManageLeadStatusPageState createState() => ManageLeadStatusPageState();
}

class ManageLeadStatusPageState extends State<ManageLeadStatusPage> {
  String? date;

  int startTime = DateTime(1900).millisecondsSinceEpoch;
  int endTime = DateTime.now().millisecondsSinceEpoch;
  TextStyleElements? styleElements;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {});
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        appBar: appAppBar().getCustomAppBar(
          context,
          actions: [IconButton(onPressed: (){openManageRedemption();}, icon: Icon(Icons.add))],
          appBarTitle: "Lead status",
          onBackButtonPress: () {
            Navigator.pop(context);
          },
        ),
        body: ListView(
          children: [


            InkWell(
              onTap: () {},
              child: Card(
                  elevation: 0,
                  margin: EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: CircularAvatar(
                        height: 30,
                        width: 30,
                        color: HexColor(AppColors.appMainColor),
                        name: "New",
                      ),
                      title: Text(
                        "New",
                        style: styleElements!.subtitle1ThemeScalable(context),
                      ),

                      trailing: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Icon(Icons.more_vert),
                      ),
                    ),
                  )),
            ),
            InkWell(
              onTap: () {},
              child: Card(
                  elevation: 0,
                  margin: EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: CircularAvatar(
                        height: 30,
                        width: 30,
                        color: HexColor(AppColors.appMainColor),
                        name: "Open",
                      ),
                      title: Text(
                        "Open",
                        style: styleElements!.subtitle1ThemeScalable(context),
                      ),

                      trailing: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Icon(Icons.more_vert),
                      ),
                    ),
                  )),
            ),
            InkWell(
              onTap: () {},
              child: Card(
                  elevation: 0,
                  margin: EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: CircularAvatar(
                        height: 30,
                        width: 30,
                        color: HexColor(AppColors.appMainColor),
                        name: "Closed",
                      ),
                      title: Text(
                        "Closed",
                        style: styleElements!.subtitle1ThemeScalable(context),
                      ),

                      trailing: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Icon(Icons.more_vert),
                      ),
                    ),
                  )),
            ),
            InkWell(
              onTap: () {},
              child: Card(
                  elevation: 0,
                  margin: EdgeInsets.only(left: 4, right: 4, top: 1, bottom: 1),
                  child: Padding(
                    padding: EdgeInsets.only(top: 8, bottom: 8, left: 8),
                    child: ListTile(
                      leading: CircularAvatar(
                        height: 30,
                        width: 30,
                        color: HexColor(AppColors.appMainColor),
                        name: "Qualified",
                      ),
                      title: Text(
                        "Qualified",
                        style: styleElements!.subtitle1ThemeScalable(context),
                      ),

                      trailing: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Icon(Icons.more_vert),
                      ),
                    ),
                  )),
            ),
          ],
        ),
      ),
    );
  }

  openManageRedemption() {
    showModalBottomSheet(
      context: context,
      isScrollControlled: true,
      shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(12), topRight: Radius.circular(12))),
      builder: (BuildContext context) {
        return Wrap(
          children: [
            CommonHelpdeskSheet(
              child: EditStatusSheet(
                isBothValueRequired: true,
                firstItemHint:"Enter coins",
                firstItemTag:"Enter coins that the status gives",
                secondItemHint:
                "Add or edit status",
                secondItemTag:
                "Add or edit status",
                firstItemIcon: Icon(
                  Icons.money_off_csred_outlined,

                ),
                title:'Add edit status',
                subTitle:"You can add or edit the status of the lead.",
                secondItemIcon: Icon(
                  Icons.attach_money,
                  color: HexColor(AppColors.appColorRed),
                ),
                nextCallBack: (num cash, num coin) {

                },
              ),
            ),
          ],
        );
      },
    );
  }
  void refresh() {
    // fetchData(startTime, endTime);
  }


}

class ManageLeadStatusPageDisplayWidget extends StatelessWidget {
  final String? title;
  final String? subtitle;
  final bool isIconShow;
  final Function? onPressed;
  final Widget? icon;

  ManageLeadStatusPageDisplayWidget(
      {this.title,
        this.subtitle,
        this.isIconShow = false,
        this.onPressed,
        this.icon});

  @override
  Widget build(BuildContext context) {
    var styleElements = TextStyleElements(context);
    return appListCard(
      onTap: onPressed,
      padding: EdgeInsets.only(left: 8, bottom: 6, right: 8, top: 8),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Visibility(visible: isIconShow, child: icon ?? Container()),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  title ?? "",
                  style: isIconShow
                      ? styleElements.subtitle1ThemeScalable(context).copyWith(
                    fontWeight: FontWeight.bold,
                  )
                      : styleElements.bodyText2ThemeScalable(context),
                  maxLines: 1,
                  overflow: TextOverflow.ellipsis,
                ),
                isIconShow ? Container() : Spacer(),
                Row(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    if (!isIconShow) Spacer(),
                    if (isIconShow)
                      Flexible(
                        child: Text(
                          subtitle ?? "",
                          style: styleElements.bodyText2ThemeScalable(context),
                        ),
                      ),
                    if (!isIconShow)
                      Text(
                        subtitle ?? "",
                        style: styleElements
                            .subtitle1ThemeScalable(context)
                            .copyWith(
                          fontWeight: FontWeight.bold,
                        ),
                      ),
                  ],
                )
              ],
            ),
          ),
        ],
      ),
    );
  }
}
