import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:lead_management/presentation/utils/localization.dart';

import '../../data/models/product_catalog.dart';
import '../../data/models/product_response.dart';
import '../common_widgets/product_card.dart';
import '../common_widgets/product_sheet.dart';
import '../utils/CustomPaginator.dart';
import '../utils/colors.dart';
import '../utils/common_helpdesk_sheet.dart';
import '../utils/custom_app_bar.dart';
import '../utils/customcard.dart';
import '../utils/hexColors.dart';
import '../utils/paginator.dart';
import '../utils/text_styling.dart';
import 'common_product_manage_sheet.dart';

enum ProductBrandCategoryCatalogueType {
  category,
  brand,
  catalogue,
  tax,
  product
}

class ManageProductBrandCategoryCatalogue extends StatefulWidget {
  final ProductBrandCategoryCatalogueType type;

  const ManageProductBrandCategoryCatalogue({required this.type});

  @override
  ManageProductBrandCategoryCatalogueState createState() =>
      ManageProductBrandCategoryCatalogueState();
}

class ManageProductBrandCategoryCatalogueState
    extends State<ManageProductBrandCategoryCatalogue> {
  late TextStyleElements styleElements;
  final GlobalKey<TypeListWidgetState> typeListKey = GlobalKey();

  int count = 0;

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        appBar: appAppBar().getCustomAppBarWithSearch(context,
            centerTitle: false,
            appBarTitle: _getAppBarTitle(), onBackButtonPress: () {
          Navigator.pop(context);
        }, actions: [
          Padding(
            padding: const EdgeInsets.all(16.0),
            child: InkWell(
                onTap: (){
                  Navigator.push(context,
                      MaterialPageRoute(builder: (BuildContext context) {
                        return    ProductSheet(
                            nextCallBack: (num cash, num coin) {  }, title: '', subTitle: '',);
                      }));

                },



                child: Text("Submit",    style: styleElements.subtitle1ThemeScalable(context).copyWith(color: HexColor(AppColors.blueApp),fontWeight: FontWeight.bold))),
          ),
          IconButton(
            onPressed: () {},
            icon: const Icon(
              Icons.segment,
              size: 30,
            ),
          )
        ], onSearchValueChanged: (String value) {}),
        body: NestedScrollView(
          headerSliverBuilder: (BuildContext context, bool innerBoxIsScrolled) {
            return [
              SliverToBoxAdapter(
                child: appListCard(
                  color: HexColor(AppColors.appColorBlack16),
                  padding:
                      const EdgeInsets.symmetric(vertical: 16, horizontal: 16),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      Text(
                 "Select the products that your lead is looking for.",
                        style: styleElements.subtitle1ThemeScalable(context).copyWith(color: HexColor(AppColors.appColorBlack85)),
                      ),
                      Text(
                        "4 Items are selected",
                        style: styleElements.subtitle2ThemeScalable(context).copyWith(color: HexColor(AppColors.blueApp)),
                      ),
                    ],
                  ),
                ),
              ),
              SliverToBoxAdapter(
                child: Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Text(
                    getCount(count),
                    style: styleElements
                        .subtitle1ThemeScalable(context)
                        .copyWith(fontWeight: FontWeight.bold),
                  ),
                ),
              )
            ];
          },
          body: TypeListWidget(
              type: widget.type,
              key: typeListKey,
              fromType: widget.type,
              isSelect: false,
              countCallback: (int count) {
                setState(() {
                  this.count = count;
                });
              }),
        ),
      ),
    );
  }



  String getCount(int count) {
    if (widget.type == ProductBrandCategoryCatalogueType.category) {
      return LeadsLocalizations.of(context)!.translate('count_categories',
          arguments: {"count": count.toString()});
    } else if (widget.type == ProductBrandCategoryCatalogueType.catalogue) {
      return LeadsLocalizations.of(context)!
          .translate('count_catalogue', arguments: {"count": count.toString()});
    } else if (widget.type == ProductBrandCategoryCatalogueType.brand) {
      return LeadsLocalizations.of(context)!
          .translate('count_brand', arguments: {"count": count.toString()});
    } else if (widget.type == ProductBrandCategoryCatalogueType.product) {
      return LeadsLocalizations.of(context)!
          .translate('count_products', arguments: {"count": count.toString()});
    } else {
      return "0";
    }
  }

  String _getBannerContent() {
    switch (widget.type) {
      case ProductBrandCategoryCatalogueType.category:
        {
          return LeadsLocalizations.of(context)!
              .translate("manage_category_banner");
        }
      case ProductBrandCategoryCatalogueType.catalogue:
        {
          return LeadsLocalizations.of(context)!
              .translate("manage_catologue_banner");
        }
      case ProductBrandCategoryCatalogueType.brand:
        {
          return LeadsLocalizations.of(context)!
              .translate("manage_brand_banner");
        }
      case ProductBrandCategoryCatalogueType.product:
        {
          return LeadsLocalizations.of(context)!
              .translate("manage_products_banner");
        }
      default:
        {
          return "";
        }
    }
  }

  String _getAppBarTitle() {
    switch (widget.type) {
      case ProductBrandCategoryCatalogueType.category:
        {
          return LeadsLocalizations.of(context)!
              .translate('category_page_title');
        }
      case ProductBrandCategoryCatalogueType.catalogue:
        {
          return LeadsLocalizations.of(context)!
              .translate('catalogue_page_title');
        }
      case ProductBrandCategoryCatalogueType.brand:
        {
          return LeadsLocalizations.of(context)!.translate('brand_page_title');
        }
      case ProductBrandCategoryCatalogueType.product:
        {
          return "Select products";
        }
      default:
        {
          return "";
        }
    }
  }
}

class TypeListWidget extends StatefulWidget {
  final ProductBrandCategoryCatalogueType type;
  final ProductBrandCategoryCatalogueType fromType;
  final bool isSelect;
  final Function(int) countCallback;

  const TypeListWidget(
      {Key? key,
      required this.type,
      this.isSelect = false,
      required this.fromType,
      required this.countCallback})
      : super(key: key);

  @override
  TypeListWidgetState createState() => TypeListWidgetState();
}

class TypeListWidgetState extends State<TypeListWidget> {
  ProductCatalogResponse? catalogData;
  ProductResponse? productData;

  GlobalKey<PaginatorState> categoryKey = GlobalKey();
  GlobalKey<PaginatorState> brandKey = GlobalKey();

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {
      fetchData();
    });
  }

  void fetchData() async {
    if (widget.type == ProductBrandCategoryCatalogueType.catalogue) {
      var data = await rootBundle
          .loadString('packages/lead_management/assets/lang/catalog_list.json');
      setState(() {
        catalogData = ProductCatalogResponse.fromJson(json.decode(data));
      });
    } else {
      var data = await rootBundle
          .loadString('packages/lead_management/assets/lang/product_list.json');
      setState(() {
        productData = ProductResponse.fromJson(json.decode(data));
      });
    }
    widget.countCallback(2);
  }

  void refresh() {
    if (widget.type == ProductBrandCategoryCatalogueType.brand) {
      brandKey.currentState!.changeState(resetState: true);
    } else if (widget.type == ProductBrandCategoryCatalogueType.category) {
      categoryKey.currentState!.changeState(resetState: true);
    }
  }

  @override
  Widget build(BuildContext context) {
    if (widget.type == ProductBrandCategoryCatalogueType.product) {
      return ListView.builder(
        itemCount: productData!.rows!.length??0,
        shrinkWrap: true,
        itemBuilder: (BuildContext context, int index) {
          return _getListWidget(index);
        },
      );
    }

    return Container();
  }

  Widget _getListWidget(int index) {
    switch (widget.type) {
      case ProductBrandCategoryCatalogueType.product:
        {
          var product = productData!.rows![index];
          return InkWell(
            onTap: () {},
            child: ProductListCard(
                productData: product,
                moreCallback: () {
                  showModalBottomSheet(
                    context: context,
                    shape: const RoundedRectangleBorder(
                        borderRadius: BorderRadius.only(
                            topLeft: Radius.circular(12),
                            topRight: Radius.circular(12))),
                    builder: (BuildContext context) {
                      return CommonManageProductSheets(
                          title: LeadsLocalizations.of(context)!
                              .translate('manage_products'),
                          fromType: widget.fromType,
                          callback: (value) {},
                          type: ProductBottomSheetType.product);
                    },
                  );
                }),
          );
        }
      default:
        {
          return Container();
        }
    }
  }
}
